echo script type: R
echo ">>>>>>>>running test 1"
../source/tot_info.exe  < ../inputs/universe/tst88 > ../originals/t1
echo ">>>>>>>>running test 2"
../source/tot_info.exe  < ../inputs/universe/tst34 > ../originals/t2
echo ">>>>>>>>running test 3"
../source/tot_info.exe  < ../inputs/universe/tst16 > ../originals/t3
echo ">>>>>>>>running test 4"
../source/tot_info.exe  < ../inputs/universe/jkADr.mat > ../originals/t4
echo ">>>>>>>>running test 5"
../source/tot_info.exe  < ../inputs/universe/tst6 > ../originals/t5
echo ">>>>>>>>running test 6"
../source/tot_info.exe  < ../inputs/universe/tst13 > ../originals/t6
echo ">>>>>>>>running test 7"
../source/tot_info.exe  < ../inputs/universe/tst108 > ../originals/t7
echo ">>>>>>>>running test 8"
../source/tot_info.exe  < ../inputs/universe/tst17 > ../originals/t8
echo ">>>>>>>>running test 9"
../source/tot_info.exe  < ../inputs/universe/tst29 > ../originals/t9
echo ">>>>>>>>running test 10"
../source/tot_info.exe  < ../inputs/universe/tst89 > ../originals/t10
echo ">>>>>>>>running test 11"
../source/tot_info.exe  < ../inputs/universe/tst8 > ../originals/t11
echo ">>>>>>>>running test 12"
../source/tot_info.exe  < ../inputs/universe/tst9 > ../originals/t12
echo ">>>>>>>>running test 13"
../source/tot_info.exe  < ../inputs/universe/tst55 > ../originals/t13
echo ">>>>>>>>running test 14"
../source/tot_info.exe  < ../inputs/universe/tst76 > ../originals/t14
echo ">>>>>>>>running test 15"
../source/tot_info.exe  < ../inputs/universe/tst109 > ../originals/t15
echo ">>>>>>>>running test 16"
../source/tot_info.exe  < ../inputs/universe/tst10 > ../originals/t16
echo ">>>>>>>>running test 17"
../source/tot_info.exe  < ../inputs/universe/tst15 > ../originals/t17
echo ">>>>>>>>running test 18"
../source/tot_info.exe  < ../inputs/universe/tst19 > ../originals/t18
echo ">>>>>>>>running test 19"
../source/tot_info.exe  < ../inputs/universe/tst90 > ../originals/t19
echo ">>>>>>>>running test 20"
../source/tot_info.exe  < ../inputs/universe/tst20 > ../originals/t20
echo ">>>>>>>>running test 21"
../source/tot_info.exe  < ../inputs/universe/tst56 > ../originals/t21
echo ">>>>>>>>running test 22"
../source/tot_info.exe  < ../inputs/universe/tst24 > ../originals/t22
echo ">>>>>>>>running test 23"
../source/tot_info.exe  < ../inputs/universe/tst3 > ../originals/t23
echo ">>>>>>>>running test 24"
../source/tot_info.exe  < ../inputs/universe/tst25 > ../originals/t24
echo ">>>>>>>>running test 25"
../source/tot_info.exe  < ../inputs/universe/tst50 > ../originals/t25
echo ">>>>>>>>running test 26"
../source/tot_info.exe  < ../inputs/universe/tst87 > ../originals/t26
echo ">>>>>>>>running test 27"
../source/tot_info.exe  < ../inputs/universe/tst91 > ../originals/t27
echo ">>>>>>>>running test 28"
../source/tot_info.exe  < ../inputs/universe/tst107 > ../originals/t28
echo ">>>>>>>>running test 29"
../source/tot_info.exe  < ../inputs/universe/tst27 > ../originals/t29
echo ">>>>>>>>running test 30"
../source/tot_info.exe  < ../inputs/universe/tst77 > ../originals/t30
echo ">>>>>>>>running test 31"
../source/tot_info.exe  < ../inputs/universe/tst98 > ../originals/t31
echo ">>>>>>>>running test 32"
../source/tot_info.exe  < ../inputs/universe/tst18 > ../originals/t32
echo ">>>>>>>>running test 33"
../source/tot_info.exe  < ../inputs/universe/tst28 > ../originals/t33
echo ">>>>>>>>running test 34"
../source/tot_info.exe  < ../inputs/universe/tst7 > ../originals/t34
echo ">>>>>>>>running test 35"
../source/tot_info.exe  < ../inputs/universe/tst30 > ../originals/t35
echo ">>>>>>>>running test 36"
../source/tot_info.exe  < ../inputs/universe/tst107 > ../originals/t36
echo ">>>>>>>>running test 37"
../source/tot_info.exe  < ../inputs/universe/tst32 > ../originals/t37
echo ">>>>>>>>running test 38"
../source/tot_info.exe  < ../inputs/universe/tst33 > ../originals/t38
echo ">>>>>>>>running test 39"
../source/tot_info.exe  < ../inputs/universe/tst2 > ../originals/t39
echo ">>>>>>>>running test 40"
../source/tot_info.exe  < ../inputs/universe/tst5 > ../originals/t40
echo ">>>>>>>>running test 41"
../source/tot_info.exe  < ../inputs/universe/tst92 > ../originals/t41
echo ">>>>>>>>running test 42"
../source/tot_info.exe  < ../inputs/universe/tst97 > ../originals/t42
echo ">>>>>>>>running test 43"
../source/tot_info.exe  < ../inputs/universe/tst31 > ../originals/t43
echo ">>>>>>>>running test 44"
../source/tot_info.exe  < ../inputs/universe/tst35 > ../originals/t44
echo ">>>>>>>>running test 45"
../source/tot_info.exe  < ../inputs/universe/tst21 > ../originals/t45
echo ">>>>>>>>running test 46"
../source/tot_info.exe  < ../inputs/universe/tst39 > ../originals/t46
echo ">>>>>>>>running test 47"
../source/tot_info.exe  < ../inputs/universe/tst12 > ../originals/t47
echo ">>>>>>>>running test 48"
../source/tot_info.exe  < ../inputs/universe/tst86 > ../originals/t48
echo ">>>>>>>>running test 49"
../source/tot_info.exe  < ../inputs/universe/tst106 > ../originals/t49
echo ">>>>>>>>running test 50"
../source/tot_info.exe  < ../inputs/universe/tst41 > ../originals/t50
echo ">>>>>>>>running test 51"
../source/tot_info.exe  < ../inputs/universe/tst43 > ../originals/t51
echo ">>>>>>>>running test 52"
../source/tot_info.exe  < ../inputs/universe/tst23 > ../originals/t52
echo ">>>>>>>>running test 53"
../source/tot_info.exe  < ../inputs/universe/tst115 > ../originals/t53
echo ">>>>>>>>running test 54"
../source/tot_info.exe  < ../inputs/universe/tst44 > ../originals/t54
echo ">>>>>>>>running test 55"
../source/tot_info.exe  < ../inputs/universe/tst68 > ../originals/t55
echo ">>>>>>>>running test 56"
../source/tot_info.exe  < ../inputs/universe/tst45 > ../originals/t56
echo ">>>>>>>>running test 57"
../source/tot_info.exe  < ../inputs/universe/tst4 > ../originals/t57
echo ">>>>>>>>running test 58"
../source/tot_info.exe  < ../inputs/universe/tst116 > ../originals/t58
echo ">>>>>>>>running test 59"
../source/tot_info.exe  < ../inputs/universe/tst85 > ../originals/t59
echo ">>>>>>>>running test 60"
../source/tot_info.exe  < ../inputs/universe/tst46 > ../originals/t60
echo ">>>>>>>>running test 61"
../source/tot_info.exe  < ../inputs/universe/tst47 > ../originals/t61
echo ">>>>>>>>running test 62"
../source/tot_info.exe  < ../inputs/universe/tst96 > ../originals/t62
echo ">>>>>>>>running test 63"
../source/tot_info.exe  < ../inputs/universe/tst73 > ../originals/t63
echo ">>>>>>>>running test 64"
../source/tot_info.exe  < ../inputs/universe/tst48 > ../originals/t64
echo ">>>>>>>>running test 65"
../source/tot_info.exe  < ../inputs/universe/tst101 > ../originals/t65
echo ">>>>>>>>running test 66"
../source/tot_info.exe  < ../inputs/universe/tst64 > ../originals/t66
echo ">>>>>>>>running test 67"
../source/tot_info.exe  < ../inputs/universe/tst84 > ../originals/t67
echo ">>>>>>>>running test 68"
../source/tot_info.exe  < ../inputs/universe/tst49 > ../originals/t68
echo ">>>>>>>>running test 69"
../source/tot_info.exe  < ../inputs/universe/tst95 > ../originals/t69
echo ">>>>>>>>running test 70"
../source/tot_info.exe  < ../inputs/universe/tst14 > ../originals/t70
echo ">>>>>>>>running test 71"
../source/tot_info.exe  < ../inputs/universe/tst51 > ../originals/t71
echo ">>>>>>>>running test 72"
../source/tot_info.exe  < ../inputs/universe/tst115 > ../originals/t72
echo ">>>>>>>>running test 73"
../source/tot_info.exe  < ../inputs/universe/tst72 > ../originals/t73
echo ">>>>>>>>running test 74"
../source/tot_info.exe  < ../inputs/universe/tst60 > ../originals/t74
echo ">>>>>>>>running test 75"
../source/tot_info.exe  < ../inputs/universe/tst83 > ../originals/t75
echo ">>>>>>>>running test 76"
../source/tot_info.exe  < ../inputs/universe/tst38 > ../originals/t76
echo ">>>>>>>>running test 77"
../source/tot_info.exe  < ../inputs/universe/tst52 > ../originals/t77
echo ">>>>>>>>running test 78"
../source/tot_info.exe  < ../inputs/universe/tst95 > ../originals/t78
echo ">>>>>>>>running test 79"
../source/tot_info.exe  < ../inputs/universe/tst82 > ../originals/t79
echo ">>>>>>>>running test 80"
../source/tot_info.exe  < ../inputs/universe/tst114 > ../originals/t80
echo ">>>>>>>>running test 81"
../source/tot_info.exe  < ../inputs/universe/tst75 > ../originals/t81
echo ">>>>>>>>running test 82"
../source/tot_info.exe  < ../inputs/universe/tst36 > ../originals/t82
echo ">>>>>>>>running test 83"
../source/tot_info.exe  < ../inputs/universe/tst54 > ../originals/t83
echo ">>>>>>>>running test 84"
../source/tot_info.exe  < ../inputs/universe/tst57 > ../originals/t84
echo ">>>>>>>>running test 85"
../source/tot_info.exe  < ../inputs/universe/tst79 > ../originals/t85
echo ">>>>>>>>running test 86"
../source/tot_info.exe  < ../inputs/universe/tst58 > ../originals/t86
echo ">>>>>>>>running test 87"
../source/tot_info.exe  < ../inputs/universe/tst94 > ../originals/t87
echo ">>>>>>>>running test 88"
../source/tot_info.exe  < ../inputs/universe/tst59 > ../originals/t88
echo ">>>>>>>>running test 89"
../source/tot_info.exe  < ../inputs/universe/tst11 > ../originals/t89
echo ">>>>>>>>running test 90"
../source/tot_info.exe  < ../inputs/universe/tst116 > ../originals/t90
echo ">>>>>>>>running test 91"
../source/tot_info.exe  < ../inputs/universe/tst40 > ../originals/t91
echo ">>>>>>>>running test 92"
../source/tot_info.exe  < ../inputs/universe/tst93 > ../originals/t92
echo ">>>>>>>>running test 93"
../source/tot_info.exe  < ../inputs/universe/tst61 > ../originals/t93
echo ">>>>>>>>running test 94"
../source/tot_info.exe  < ../inputs/universe/tst22 > ../originals/t94
echo ">>>>>>>>running test 95"
../source/tot_info.exe  < ../inputs/universe/tst42 > ../originals/t95
echo ">>>>>>>>running test 96"
../source/tot_info.exe  < ../inputs/universe/tst62 > ../originals/t96
echo ">>>>>>>>running test 97"
../source/tot_info.exe  < ../inputs/universe/tst104 > ../originals/t97
echo ">>>>>>>>running test 98"
../source/tot_info.exe  < ../inputs/universe/tst37 > ../originals/t98
echo ">>>>>>>>running test 99"
../source/tot_info.exe  < ../inputs/universe/tst81 > ../originals/t99
echo ">>>>>>>>running test 100"
../source/tot_info.exe  < ../inputs/universe/tst63 > ../originals/t100
echo ">>>>>>>>running test 101"
../source/tot_info.exe  < ../inputs/universe/tst113 > ../originals/t101
echo ">>>>>>>>running test 102"
../source/tot_info.exe  < ../inputs/universe/tst112 > ../originals/t102
echo ">>>>>>>>running test 103"
../source/tot_info.exe  < ../inputs/universe/tst26 > ../originals/t103
echo ">>>>>>>>running test 104"
../source/tot_info.exe  < ../inputs/universe/tst65 > ../originals/t104
echo ">>>>>>>>running test 105"
../source/tot_info.exe  < ../inputs/universe/tst71 > ../originals/t105
echo ">>>>>>>>running test 106"
../source/tot_info.exe  < ../inputs/universe/tst111 > ../originals/t106
echo ">>>>>>>>running test 107"
../source/tot_info.exe  < ../inputs/universe/tst74 > ../originals/t107
echo ">>>>>>>>running test 108"
../source/tot_info.exe  < ../inputs/universe/tst102 > ../originals/t108
echo ">>>>>>>>running test 109"
../source/tot_info.exe  < ../inputs/universe/tst66 > ../originals/t109
echo ">>>>>>>>running test 110"
../source/tot_info.exe  < ../inputs/universe/tst117 > ../originals/t110
echo ">>>>>>>>running test 111"
../source/tot_info.exe  < ../inputs/universe/tst67 > ../originals/t111
echo ">>>>>>>>running test 112"
../source/tot_info.exe  < ../inputs/universe/tst69 > ../originals/t112
echo ">>>>>>>>running test 113"
../source/tot_info.exe  < ../inputs/universe/tst70 > ../originals/t113
echo ">>>>>>>>running test 114"
../source/tot_info.exe  < ../inputs/universe/tst1 > ../originals/t114
echo ">>>>>>>>running test 115"
../source/tot_info.exe  < ../inputs/universe/tst103 > ../originals/t115
echo ">>>>>>>>running test 116"
../source/tot_info.exe  < ../inputs/universe/tst80 > ../originals/t116
echo ">>>>>>>>running test 117"
../source/tot_info.exe  < ../inputs/universe/test3 > ../originals/t117
echo ">>>>>>>>running test 118"
../source/tot_info.exe  < ../inputs/universe/test5 > ../originals/t118
echo ">>>>>>>>running test 119"
../source/tot_info.exe  < ../inputs/universe/test32 > ../originals/t119
echo ">>>>>>>>running test 120"
../source/tot_info.exe  < ../inputs/universe/test7 > ../originals/t120
echo ">>>>>>>>running test 121"
../source/tot_info.exe  < ../inputs/universe/test8 > ../originals/t121
echo ">>>>>>>>running test 122"
../source/tot_info.exe  < ../inputs/universe/test9 > ../originals/t122
echo ">>>>>>>>running test 123"
../source/tot_info.exe  < ../inputs/universe/test10 > ../originals/t123
echo ">>>>>>>>running test 124"
../source/tot_info.exe  < ../inputs/universe/test19 > ../originals/t124
echo ">>>>>>>>running test 125"
../source/tot_info.exe  < ../inputs/universe/test31 > ../originals/t125
echo ">>>>>>>>running test 126"
../source/tot_info.exe  < ../inputs/universe/test1 > ../originals/t126
echo ">>>>>>>>running test 127"
../source/tot_info.exe  < ../inputs/universe/test4 > ../originals/t127
echo ">>>>>>>>running test 128"
../source/tot_info.exe  < ../inputs/universe/test39 > ../originals/t128
echo ">>>>>>>>running test 129"
../source/tot_info.exe  < ../inputs/universe/test11 > ../originals/t129
echo ">>>>>>>>running test 130"
../source/tot_info.exe  < ../inputs/universe/test30 > ../originals/t130
echo ">>>>>>>>running test 131"
../source/tot_info.exe  < ../inputs/universe/test14 > ../originals/t131
echo ">>>>>>>>running test 132"
../source/tot_info.exe  < ../inputs/universe/test13 > ../originals/t132
echo ">>>>>>>>running test 133"
../source/tot_info.exe  < ../inputs/universe/test15 > ../originals/t133
echo ">>>>>>>>running test 134"
../source/tot_info.exe  < ../inputs/universe/test16 > ../originals/t134
echo ">>>>>>>>running test 135"
../source/tot_info.exe  < ../inputs/universe/test17 > ../originals/t135
echo ">>>>>>>>running test 136"
../source/tot_info.exe  < ../inputs/universe/test6 > ../originals/t136
echo ">>>>>>>>running test 137"
../source/tot_info.exe  < ../inputs/universe/test33 > ../originals/t137
echo ">>>>>>>>running test 138"
../source/tot_info.exe  < ../inputs/universe/test34 > ../originals/t138
echo ">>>>>>>>running test 139"
../source/tot_info.exe  < ../inputs/universe/test35 > ../originals/t139
echo ">>>>>>>>running test 140"
../source/tot_info.exe  < ../inputs/universe/test36 > ../originals/t140
echo ">>>>>>>>running test 141"
../source/tot_info.exe  < ../inputs/universe/test18 > ../originals/t141
echo ">>>>>>>>running test 142"
../source/tot_info.exe  < ../inputs/universe/test37 > ../originals/t142
echo ">>>>>>>>running test 143"
../source/tot_info.exe  < ../inputs/universe/test40 > ../originals/t143
echo ">>>>>>>>running test 144"
../source/tot_info.exe  < ../inputs/universe/test38 > ../originals/t144
echo ">>>>>>>>running test 145"
../source/tot_info.exe  < ../inputs/universe/tstt1.mat > ../originals/t145
echo ">>>>>>>>running test 146"
../source/tot_info.exe  < ../inputs/universe/jk2AAZ.mat > ../originals/t146
echo ">>>>>>>>running test 147"
../source/tot_info.exe  < ../inputs/universe/jk2ABS.mat > ../originals/t147
echo ">>>>>>>>running test 148"
../source/tot_info.exe  < ../inputs/universe/jk2ABk.mat > ../originals/t148
echo ">>>>>>>>running test 149"
../source/tot_info.exe  < ../inputs/universe/jk1AA_.mat > ../originals/t149
echo ">>>>>>>>running test 150"
../source/tot_info.exe  < ../inputs/universe/tst29.mat > ../originals/t150
echo ">>>>>>>>running test 151"
../source/tot_info.exe  < ../inputs/universe/jk1AAS.mat > ../originals/t151
echo ">>>>>>>>running test 152"
../source/tot_info.exe  < ../inputs/universe/jkAAY.mat > ../originals/t152
echo ">>>>>>>>running test 153"
../source/tot_info.exe  < ../inputs/universe/jk2AAy.mat > ../originals/t153
echo ">>>>>>>>running test 154"
../source/tot_info.exe  < ../inputs/universe/jkAAQ.mat > ../originals/t154
echo ">>>>>>>>running test 155"
../source/tot_info.exe  < ../inputs/universe/tst21.mat > ../originals/t155
echo ">>>>>>>>running test 156"
../source/tot_info.exe  < ../inputs/universe/jkAAZ.mat > ../originals/t156
echo ">>>>>>>>running test 157"
../source/tot_info.exe  < ../inputs/universe/jk2ABq.mat > ../originals/t157
echo ">>>>>>>>running test 158"
../source/tot_info.exe  < ../inputs/universe/jk1ABq.mat > ../originals/t158
echo ">>>>>>>>running test 159"
../source/tot_info.exe  < ../inputs/universe/jk2AAX.mat > ../originals/t159
echo ">>>>>>>>running test 160"
../source/tot_info.exe  < ../inputs/universe/jkADr.mat > ../originals/t160
echo ">>>>>>>>running test 161"
../source/tot_info.exe  < ../inputs/universe/jkAFi.mat > ../originals/t161
echo ">>>>>>>>running test 162"
../source/tot_info.exe  < ../inputs/universe/jk2AAS.mat > ../originals/t162
echo ">>>>>>>>running test 163"
../source/tot_info.exe  < ../inputs/universe/tst2f.mat > ../originals/t163
echo ">>>>>>>>running test 164"
../source/tot_info.exe  < ../inputs/universe/tst23.mat > ../originals/t164
echo ">>>>>>>>running test 165"
../source/tot_info.exe  < ../inputs/universe/tst2E.mat > ../originals/t165
echo ">>>>>>>>running test 166"
../source/tot_info.exe  < ../inputs/universe/test72 > ../originals/t166
echo ">>>>>>>>running test 167"
../source/tot_info.exe  < ../inputs/universe/test77 > ../originals/t167
echo ">>>>>>>>running test 168"
../source/tot_info.exe  < ../inputs/universe/test80 > ../originals/t168
echo ">>>>>>>>running test 169"
../source/tot_info.exe  < ../inputs/universe/test51 > ../originals/t169
echo ">>>>>>>>running test 170"
../source/tot_info.exe  < ../inputs/universe/test52 > ../originals/t170
echo ">>>>>>>>running test 171"
../source/tot_info.exe  < ../inputs/universe/test53 > ../originals/t171
echo ">>>>>>>>running test 172"
../source/tot_info.exe  < ../inputs/universe/test54 > ../originals/t172
echo ">>>>>>>>running test 173"
../source/tot_info.exe  < ../inputs/universe/test56 > ../originals/t173
echo ">>>>>>>>running test 174"
../source/tot_info.exe  < ../inputs/universe/test57 > ../originals/t174
echo ">>>>>>>>running test 175"
../source/tot_info.exe  < ../inputs/universe/test60 > ../originals/t175
echo ">>>>>>>>running test 176"
../source/tot_info.exe  < ../inputs/universe/test42 > ../originals/t176
echo ">>>>>>>>running test 177"
../source/tot_info.exe  < ../inputs/universe/test75 > ../originals/t177
echo ">>>>>>>>running test 178"
../source/tot_info.exe  < ../inputs/universe/test73 > ../originals/t178
echo ">>>>>>>>running test 179"
../source/tot_info.exe  < ../inputs/universe/test99 > ../originals/t179
echo ">>>>>>>>running test 180"
../source/tot_info.exe  < ../inputs/universe/test43 > ../originals/t180
echo ">>>>>>>>running test 181"
../source/tot_info.exe  < ../inputs/universe/test90 > ../originals/t181
echo ">>>>>>>>running test 182"
../source/tot_info.exe  < ../inputs/universe/test45 > ../originals/t182
echo ">>>>>>>>running test 183"
../source/tot_info.exe  < ../inputs/universe/test46 > ../originals/t183
echo ">>>>>>>>running test 184"
../source/tot_info.exe  < ../inputs/universe/test78 > ../originals/t184
echo ">>>>>>>>running test 185"
../source/tot_info.exe  < ../inputs/universe/test83 > ../originals/t185
echo ">>>>>>>>running test 186"
../source/tot_info.exe  < ../inputs/universe/test59 > ../originals/t186
echo ">>>>>>>>running test 187"
../source/tot_info.exe  < ../inputs/universe/test49 > ../originals/t187
echo ">>>>>>>>running test 188"
../source/tot_info.exe  < ../inputs/universe/test50 > ../originals/t188
echo ">>>>>>>>running test 189"
../source/tot_info.exe  < ../inputs/universe/test61 > ../originals/t189
echo ">>>>>>>>running test 190"
../source/tot_info.exe  < ../inputs/universe/test63 > ../originals/t190
echo ">>>>>>>>running test 191"
../source/tot_info.exe  < ../inputs/universe/test74 > ../originals/t191
echo ">>>>>>>>running test 192"
../source/tot_info.exe  < ../inputs/universe/test64 > ../originals/t192
echo ">>>>>>>>running test 193"
../source/tot_info.exe  < ../inputs/universe/test79 > ../originals/t193
echo ">>>>>>>>running test 194"
../source/tot_info.exe  < ../inputs/universe/test87 > ../originals/t194
echo ">>>>>>>>running test 195"
../source/tot_info.exe  < ../inputs/universe/test66 > ../originals/t195
echo ">>>>>>>>running test 196"
../source/tot_info.exe  < ../inputs/universe/test67 > ../originals/t196
echo ">>>>>>>>running test 197"
../source/tot_info.exe  < ../inputs/universe/test48 > ../originals/t197
echo ">>>>>>>>running test 198"
../source/tot_info.exe  < ../inputs/universe/test100 > ../originals/t198
echo ">>>>>>>>running test 199"
../source/tot_info.exe  < ../inputs/universe/test92 > ../originals/t199
echo ">>>>>>>>running test 200"
../source/tot_info.exe  < ../inputs/universe/test68 > ../originals/t200
echo ">>>>>>>>running test 201"
../source/tot_info.exe  < ../inputs/universe/test76 > ../originals/t201
echo ">>>>>>>>running test 202"
../source/tot_info.exe  < ../inputs/universe/test69 > ../originals/t202
echo ">>>>>>>>running test 203"
../source/tot_info.exe  < ../inputs/universe/test44 > ../originals/t203
echo ">>>>>>>>running test 204"
../source/tot_info.exe  < ../inputs/universe/test47 > ../originals/t204
echo ">>>>>>>>running test 205"
../source/tot_info.exe  < ../inputs/universe/test81 > ../originals/t205
echo ">>>>>>>>running test 206"
../source/tot_info.exe  < ../inputs/universe/test84 > ../originals/t206
echo ">>>>>>>>running test 207"
../source/tot_info.exe  < ../inputs/universe/test98 > ../originals/t207
echo ">>>>>>>>running test 208"
../source/tot_info.exe  < ../inputs/universe/test58 > ../originals/t208
echo ">>>>>>>>running test 209"
../source/tot_info.exe  < ../inputs/universe/test88 > ../originals/t209
echo ">>>>>>>>running test 210"
../source/tot_info.exe  < ../inputs/universe/test89 > ../originals/t210
echo ">>>>>>>>running test 211"
../source/tot_info.exe  < ../inputs/universe/test91 > ../originals/t211
echo ">>>>>>>>running test 212"
../source/tot_info.exe  < ../inputs/universe/test70 > ../originals/t212
echo ">>>>>>>>running test 213"
../source/tot_info.exe  < ../inputs/universe/test82 > ../originals/t213
echo ">>>>>>>>running test 214"
../source/tot_info.exe  < ../inputs/universe/test93 > ../originals/t214
echo ">>>>>>>>running test 215"
../source/tot_info.exe  < ../inputs/universe/test94 > ../originals/t215
echo ">>>>>>>>running test 216"
../source/tot_info.exe  < ../inputs/universe/test65 > ../originals/t216
echo ">>>>>>>>running test 217"
../source/tot_info.exe  < ../inputs/universe/test71 > ../originals/t217
echo ">>>>>>>>running test 218"
../source/tot_info.exe  < ../inputs/universe/test85 > ../originals/t218
echo ">>>>>>>>running test 219"
../source/tot_info.exe  < ../inputs/universe/test101 > ../originals/t219
echo ">>>>>>>>running test 220"
../source/tot_info.exe  < ../inputs/universe/test102 > ../originals/t220
echo ">>>>>>>>running test 221"
../source/tot_info.exe  < ../inputs/universe/test103 > ../originals/t221
echo ">>>>>>>>running test 222"
../source/tot_info.exe  < ../inputs/universe/test104 > ../originals/t222
echo ">>>>>>>>running test 223"
../source/tot_info.exe  < ../inputs/universe/test105 > ../originals/t223
echo ">>>>>>>>running test 224"
../source/tot_info.exe  < ../inputs/universe/test106 > ../originals/t224
echo ">>>>>>>>running test 225"
../source/tot_info.exe  < ../inputs/universe/test107 > ../originals/t225
echo ">>>>>>>>running test 226"
../source/tot_info.exe  < ../inputs/universe/test108 > ../originals/t226
echo ">>>>>>>>running test 227"
../source/tot_info.exe  < ../inputs/universe/test1.inc > ../originals/t227
echo ">>>>>>>>running test 228"
../source/tot_info.exe  < ../inputs/universe/test3.inc > ../originals/t228
echo ">>>>>>>>running test 229"
../source/tot_info.exe  < ../inputs/universe/test4.inc > ../originals/t229
echo ">>>>>>>>running test 230"
../source/tot_info.exe  < ../inputs/universe/test5.inc > ../originals/t230
echo ">>>>>>>>running test 231"
../source/tot_info.exe  < ../inputs/universe/test6.inc > ../originals/t231
echo ">>>>>>>>running test 232"
../source/tot_info.exe  < ../inputs/universe/test7.inc > ../originals/t232
echo ">>>>>>>>running test 233"
../source/tot_info.exe  < ../inputs/universe/test8.inc > ../originals/t233
echo ">>>>>>>>running test 234"
../source/tot_info.exe  < ../inputs/universe/test9.inc > ../originals/t234
echo ">>>>>>>>running test 235"
../source/tot_info.exe  < ../inputs/universe/test10.inc > ../originals/t235
echo ">>>>>>>>running test 236"
../source/tot_info.exe  < ../inputs/universe/test11.inc > ../originals/t236
echo ">>>>>>>>running test 237"
../source/tot_info.exe  < ../inputs/universe/test13.inc > ../originals/t237
echo ">>>>>>>>running test 238"
../source/tot_info.exe  < ../inputs/universe/test14.inc > ../originals/t238
echo ">>>>>>>>running test 239"
../source/tot_info.exe  < ../inputs/universe/test15.inc > ../originals/t239
echo ">>>>>>>>running test 240"
../source/tot_info.exe  < ../inputs/universe/test16.inc > ../originals/t240
echo ">>>>>>>>running test 241"
../source/tot_info.exe  < ../inputs/universe/test17.inc > ../originals/t241
echo ">>>>>>>>running test 242"
../source/tot_info.exe  < ../inputs/universe/test18.inc > ../originals/t242
echo ">>>>>>>>running test 243"
../source/tot_info.exe  < ../inputs/universe/test19.inc > ../originals/t243
echo ">>>>>>>>running test 244"
../source/tot_info.exe  < ../inputs/universe/test20.inc > ../originals/t244
echo ">>>>>>>>running test 245"
../source/tot_info.exe  < ../inputs/universe/test21.inc > ../originals/t245
echo ">>>>>>>>running test 246"
../source/tot_info.exe  < ../inputs/universe/test22.inc > ../originals/t246
echo ">>>>>>>>running test 247"
../source/tot_info.exe  < ../inputs/universe/test23.inc > ../originals/t247
echo ">>>>>>>>running test 248"
../source/tot_info.exe  < ../inputs/universe/test24.inc > ../originals/t248
echo ">>>>>>>>running test 249"
../source/tot_info.exe  < ../inputs/universe/test25.inc > ../originals/t249
echo ">>>>>>>>running test 250"
../source/tot_info.exe  < ../inputs/universe/test26.inc > ../originals/t250
echo ">>>>>>>>running test 251"
../source/tot_info.exe  < ../inputs/universe/test27.inc > ../originals/t251
echo ">>>>>>>>running test 252"
../source/tot_info.exe  < ../inputs/universe/test28.inc > ../originals/t252
echo ">>>>>>>>running test 253"
../source/tot_info.exe  < ../inputs/universe/test29.inc > ../originals/t253
echo ">>>>>>>>running test 254"
../source/tot_info.exe  < ../inputs/universe/test30.inc > ../originals/t254
echo ">>>>>>>>running test 255"
../source/tot_info.exe  < ../inputs/universe/test31.inc > ../originals/t255
echo ">>>>>>>>running test 256"
../source/tot_info.exe  < ../inputs/universe/test32.inc > ../originals/t256
echo ">>>>>>>>running test 257"
../source/tot_info.exe  < ../inputs/universe/test33.inc > ../originals/t257
echo ">>>>>>>>running test 258"
../source/tot_info.exe  < ../inputs/universe/test34.inc > ../originals/t258
echo ">>>>>>>>running test 259"
../source/tot_info.exe  < ../inputs/universe/test35.inc > ../originals/t259
echo ">>>>>>>>running test 260"
../source/tot_info.exe  < ../inputs/universe/test36.inc > ../originals/t260
echo ">>>>>>>>running test 261"
../source/tot_info.exe  < ../inputs/universe/test37.inc > ../originals/t261
echo ">>>>>>>>running test 262"
../source/tot_info.exe  < ../inputs/universe/test38.inc > ../originals/t262
echo ">>>>>>>>running test 263"
../source/tot_info.exe  < ../inputs/universe/test39.inc > ../originals/t263
echo ">>>>>>>>running test 264"
../source/tot_info.exe  < ../inputs/universe/test40.inc > ../originals/t264
echo ">>>>>>>>running test 265"
../source/tot_info.exe  < ../inputs/universe/test41.inc > ../originals/t265
echo ">>>>>>>>running test 266"
../source/tot_info.exe  < ../inputs/universe/test42.inc > ../originals/t266
echo ">>>>>>>>running test 267"
../source/tot_info.exe  < ../inputs/universe/test43.inc > ../originals/t267
echo ">>>>>>>>running test 268"
../source/tot_info.exe  < ../inputs/universe/test44.inc > ../originals/t268
echo ">>>>>>>>running test 269"
../source/tot_info.exe  < ../inputs/universe/test45.inc > ../originals/t269
echo ">>>>>>>>running test 270"
../source/tot_info.exe  < ../inputs/universe/test46.inc > ../originals/t270
echo ">>>>>>>>running test 271"
../source/tot_info.exe  < ../inputs/universe/test47.inc > ../originals/t271
echo ">>>>>>>>running test 272"
../source/tot_info.exe  < ../inputs/universe/test48.inc > ../originals/t272
echo ">>>>>>>>running test 273"
../source/tot_info.exe  < ../inputs/universe/test49.inc > ../originals/t273
echo ">>>>>>>>running test 274"
../source/tot_info.exe  < ../inputs/universe/test50.inc > ../originals/t274
echo ">>>>>>>>running test 275"
../source/tot_info.exe  < ../inputs/universe/test51.inc > ../originals/t275
echo ">>>>>>>>running test 276"
../source/tot_info.exe  < ../inputs/universe/test52.inc > ../originals/t276
echo ">>>>>>>>running test 277"
../source/tot_info.exe  < ../inputs/universe/test53.inc > ../originals/t277
echo ">>>>>>>>running test 278"
../source/tot_info.exe  < ../inputs/universe/test54.inc > ../originals/t278
echo ">>>>>>>>running test 279"
../source/tot_info.exe  < ../inputs/universe/test55.inc > ../originals/t279
echo ">>>>>>>>running test 280"
../source/tot_info.exe  < ../inputs/universe/test56.inc > ../originals/t280
echo ">>>>>>>>running test 281"
../source/tot_info.exe  < ../inputs/universe/test57.inc > ../originals/t281
echo ">>>>>>>>running test 282"
../source/tot_info.exe  < ../inputs/universe/test58.inc > ../originals/t282
echo ">>>>>>>>running test 283"
../source/tot_info.exe  < ../inputs/universe/test59.inc > ../originals/t283
echo ">>>>>>>>running test 284"
../source/tot_info.exe  < ../inputs/universe/test60.inc > ../originals/t284
echo ">>>>>>>>running test 285"
../source/tot_info.exe  < ../inputs/universe/test61.inc > ../originals/t285
echo ">>>>>>>>running test 286"
../source/tot_info.exe  < ../inputs/universe/test62.inc > ../originals/t286
echo ">>>>>>>>running test 287"
../source/tot_info.exe  < ../inputs/universe/test63.inc > ../originals/t287
echo ">>>>>>>>running test 288"
../source/tot_info.exe  < ../inputs/universe/test64.inc > ../originals/t288
echo ">>>>>>>>running test 289"
../source/tot_info.exe  < ../inputs/universe/test65.inc > ../originals/t289
echo ">>>>>>>>running test 290"
../source/tot_info.exe  < ../inputs/universe/test66.inc > ../originals/t290
echo ">>>>>>>>running test 291"
../source/tot_info.exe  < ../inputs/universe/test67.inc > ../originals/t291
echo ">>>>>>>>running test 292"
../source/tot_info.exe  < ../inputs/universe/test68.inc > ../originals/t292
echo ">>>>>>>>running test 293"
../source/tot_info.exe  < ../inputs/universe/test69.inc > ../originals/t293
echo ">>>>>>>>running test 294"
../source/tot_info.exe  < ../inputs/universe/test70.inc > ../originals/t294
echo ">>>>>>>>running test 295"
../source/tot_info.exe  < ../inputs/universe/test71.inc > ../originals/t295
echo ">>>>>>>>running test 296"
../source/tot_info.exe  < ../inputs/universe/test72.inc > ../originals/t296
echo ">>>>>>>>running test 297"
../source/tot_info.exe  < ../inputs/universe/test73.inc > ../originals/t297
echo ">>>>>>>>running test 298"
../source/tot_info.exe  < ../inputs/universe/test74.inc > ../originals/t298
echo ">>>>>>>>running test 299"
../source/tot_info.exe  < ../inputs/universe/test75.inc > ../originals/t299
echo ">>>>>>>>running test 300"
../source/tot_info.exe  < ../inputs/universe/test76.inc > ../originals/t300
echo ">>>>>>>>running test 301"
../source/tot_info.exe  < ../inputs/universe/test77.inc > ../originals/t301
echo ">>>>>>>>running test 302"
../source/tot_info.exe  < ../inputs/universe/test78.inc > ../originals/t302
echo ">>>>>>>>running test 303"
../source/tot_info.exe  < ../inputs/universe/test79.inc > ../originals/t303
echo ">>>>>>>>running test 304"
../source/tot_info.exe  < ../inputs/universe/test80.inc > ../originals/t304
echo ">>>>>>>>running test 305"
../source/tot_info.exe  < ../inputs/universe/test81.inc > ../originals/t305
echo ">>>>>>>>running test 306"
../source/tot_info.exe  < ../inputs/universe/test82.inc > ../originals/t306
echo ">>>>>>>>running test 307"
../source/tot_info.exe  < ../inputs/universe/test83.inc > ../originals/t307
echo ">>>>>>>>running test 308"
../source/tot_info.exe  < ../inputs/universe/test84.inc > ../originals/t308
echo ">>>>>>>>running test 309"
../source/tot_info.exe  < ../inputs/universe/test85.inc > ../originals/t309
echo ">>>>>>>>running test 310"
../source/tot_info.exe  < ../inputs/universe/test86.inc > ../originals/t310
echo ">>>>>>>>running test 311"
../source/tot_info.exe  < ../inputs/universe/test87.inc > ../originals/t311
echo ">>>>>>>>running test 312"
../source/tot_info.exe  < ../inputs/universe/test88.inc > ../originals/t312
echo ">>>>>>>>running test 313"
../source/tot_info.exe  < ../inputs/universe/test89.inc > ../originals/t313
echo ">>>>>>>>running test 314"
../source/tot_info.exe  < ../inputs/universe/test90.inc > ../originals/t314
echo ">>>>>>>>running test 315"
../source/tot_info.exe  < ../inputs/universe/test91.inc > ../originals/t315
echo ">>>>>>>>running test 316"
../source/tot_info.exe  < ../inputs/universe/test92.inc > ../originals/t316
echo ">>>>>>>>running test 317"
../source/tot_info.exe  < ../inputs/universe/test93.inc > ../originals/t317
echo ">>>>>>>>running test 318"
../source/tot_info.exe  < ../inputs/universe/test94.inc > ../originals/t318
echo ">>>>>>>>running test 319"
../source/tot_info.exe  < ../inputs/universe/test95.inc > ../originals/t319
echo ">>>>>>>>running test 320"
../source/tot_info.exe  < ../inputs/universe/test96.inc > ../originals/t320
echo ">>>>>>>>running test 321"
../source/tot_info.exe  < ../inputs/universe/test97.inc > ../originals/t321
echo ">>>>>>>>running test 322"
../source/tot_info.exe  < ../inputs/universe/test98.inc > ../originals/t322
echo ">>>>>>>>running test 323"
../source/tot_info.exe  < ../inputs/universe/test99.inc > ../originals/t323
echo ">>>>>>>>running test 324"
../source/tot_info.exe  < ../inputs/universe/test100.inc > ../originals/t324
echo ">>>>>>>>running test 325"
../source/tot_info.exe  < ../inputs/universe/test101.inc > ../originals/t325
echo ">>>>>>>>running test 326"
../source/tot_info.exe  < ../inputs/universe/test102.inc > ../originals/t326
echo ">>>>>>>>running test 327"
../source/tot_info.exe  < ../inputs/universe/test103.inc > ../originals/t327
echo ">>>>>>>>running test 328"
../source/tot_info.exe  < ../inputs/universe/test104.inc > ../originals/t328
echo ">>>>>>>>running test 329"
../source/tot_info.exe  < ../inputs/universe/test106.inc > ../originals/t329
echo ">>>>>>>>running test 330"
../source/tot_info.exe  < ../inputs/universe/test107.inc > ../originals/t330
echo ">>>>>>>>running test 331"
../source/tot_info.exe  < ../inputs/universe/test108.inc > ../originals/t331
echo ">>>>>>>>running test 332"
../source/tot_info.exe  < ../inputs/universe/test109.inc > ../originals/t332
echo ">>>>>>>>running test 333"
../source/tot_info.exe  < ../inputs/universe/test110.inc > ../originals/t333
echo ">>>>>>>>running test 334"
../source/tot_info.exe  < ../inputs/universe/test111.inc > ../originals/t334
echo ">>>>>>>>running test 335"
../source/tot_info.exe  < ../inputs/universe/test112.inc > ../originals/t335
echo ">>>>>>>>running test 336"
../source/tot_info.exe  < ../inputs/universe/test113.inc > ../originals/t336
echo ">>>>>>>>running test 337"
../source/tot_info.exe  < ../inputs/universe/test114.inc > ../originals/t337
echo ">>>>>>>>running test 338"
../source/tot_info.exe  < ../inputs/universe/test115.inc > ../originals/t338
echo ">>>>>>>>running test 339"
../source/tot_info.exe  < ../inputs/universe/test116.inc > ../originals/t339
echo ">>>>>>>>running test 340"
../source/tot_info.exe  < ../inputs/universe/test117.inc > ../originals/t340
echo ">>>>>>>>running test 341"
../source/tot_info.exe  < ../inputs/universe/test118.inc > ../originals/t341
echo ">>>>>>>>running test 342"
../source/tot_info.exe  < ../inputs/universe/test119.inc > ../originals/t342
echo ">>>>>>>>running test 343"
../source/tot_info.exe  < ../inputs/universe/test120.inc > ../originals/t343
echo ">>>>>>>>running test 344"
../source/tot_info.exe  < ../inputs/universe/test121.inc > ../originals/t344
echo ">>>>>>>>running test 345"
../source/tot_info.exe  < ../inputs/universe/test122.inc > ../originals/t345
echo ">>>>>>>>running test 346"
../source/tot_info.exe  < ../inputs/universe/test123.inc > ../originals/t346
echo ">>>>>>>>running test 347"
../source/tot_info.exe  < ../inputs/universe/test124.inc > ../originals/t347
echo ">>>>>>>>running test 348"
../source/tot_info.exe  < ../inputs/universe/test125.inc > ../originals/t348
echo ">>>>>>>>running test 349"
../source/tot_info.exe  < ../inputs/universe/test126.inc > ../originals/t349
echo ">>>>>>>>running test 350"
../source/tot_info.exe  < ../inputs/universe/test127.inc > ../originals/t350
echo ">>>>>>>>running test 351"
../source/tot_info.exe  < ../inputs/universe/test128.inc > ../originals/t351
echo ">>>>>>>>running test 352"
../source/tot_info.exe  < ../inputs/universe/test129.inc > ../originals/t352
echo ">>>>>>>>running test 353"
../source/tot_info.exe  < ../inputs/universe/test130.inc > ../originals/t353
echo ">>>>>>>>running test 354"
../source/tot_info.exe  < ../inputs/universe/test131.inc > ../originals/t354
echo ">>>>>>>>running test 355"
../source/tot_info.exe  < ../inputs/universe/test132.inc > ../originals/t355
echo ">>>>>>>>running test 356"
../source/tot_info.exe  < ../inputs/universe/test133.inc > ../originals/t356
echo ">>>>>>>>running test 357"
../source/tot_info.exe  < ../inputs/universe/test134.inc > ../originals/t357
echo ">>>>>>>>running test 358"
../source/tot_info.exe  < ../inputs/universe/test135.inc > ../originals/t358
echo ">>>>>>>>running test 359"
../source/tot_info.exe  < ../inputs/universe/test136.inc > ../originals/t359
echo ">>>>>>>>running test 360"
../source/tot_info.exe  < ../inputs/universe/test137.inc > ../originals/t360
echo ">>>>>>>>running test 361"
../source/tot_info.exe  < ../inputs/universe/test138.inc > ../originals/t361
echo ">>>>>>>>running test 362"
../source/tot_info.exe  < ../inputs/universe/test139.inc > ../originals/t362
echo ">>>>>>>>running test 363"
../source/tot_info.exe  < ../inputs/universe/test140.inc	 > ../originals/t363
echo ">>>>>>>>running test 364"
../source/tot_info.exe  < ../inputs/universe/test141.inc > ../originals/t364
echo ">>>>>>>>running test 365"
../source/tot_info.exe  < ../inputs/universe/test142.inc > ../originals/t365
echo ">>>>>>>>running test 366"
../source/tot_info.exe  < ../inputs/universe/test143.inc > ../originals/t366
echo ">>>>>>>>running test 367"
../source/tot_info.exe  < ../inputs/universe/test144.inc > ../originals/t367
echo ">>>>>>>>running test 368"
../source/tot_info.exe  < ../inputs/universe/test145.inc > ../originals/t368
echo ">>>>>>>>running test 369"
../source/tot_info.exe  < ../inputs/universe/test146.inc > ../originals/t369
echo ">>>>>>>>running test 370"
../source/tot_info.exe  < ../inputs/universe/test147.inc > ../originals/t370
echo ">>>>>>>>running test 371"
../source/tot_info.exe  < ../inputs/universe/test148.inc > ../originals/t371
echo ">>>>>>>>running test 372"
../source/tot_info.exe  < ../inputs/universe/test149.inc > ../originals/t372
echo ">>>>>>>>running test 373"
../source/tot_info.exe  < ../inputs/universe/test151.inc > ../originals/t373
echo ">>>>>>>>running test 374"
../source/tot_info.exe  < ../inputs/universe/test152.inc > ../originals/t374
echo ">>>>>>>>running test 375"
../source/tot_info.exe  < ../inputs/universe/test153.inc > ../originals/t375
echo ">>>>>>>>running test 376"
../source/tot_info.exe  < ../inputs/universe/test154.inc > ../originals/t376
echo ">>>>>>>>running test 377"
../source/tot_info.exe  < ../inputs/universe/test155.inc > ../originals/t377
echo ">>>>>>>>running test 378"
../source/tot_info.exe  < ../inputs/universe/test156.inc > ../originals/t378
echo ">>>>>>>>running test 379"
../source/tot_info.exe  < ../inputs/universe/test157.inc > ../originals/t379
echo ">>>>>>>>running test 380"
../source/tot_info.exe  < ../inputs/universe/test158.inc > ../originals/t380
echo ">>>>>>>>running test 381"
../source/tot_info.exe  < ../inputs/universe/test159.inc > ../originals/t381
echo ">>>>>>>>running test 382"
../source/tot_info.exe  < ../inputs/universe/test160.inc > ../originals/t382
echo ">>>>>>>>running test 383"
../source/tot_info.exe  < ../inputs/universe/test161.inc > ../originals/t383
echo ">>>>>>>>running test 384"
../source/tot_info.exe  < ../inputs/universe/test162.inc > ../originals/t384
echo ">>>>>>>>running test 385"
../source/tot_info.exe  < ../inputs/universe/test163.inc > ../originals/t385
echo ">>>>>>>>running test 386"
../source/tot_info.exe  < ../inputs/universe/test164.inc > ../originals/t386
echo ">>>>>>>>running test 387"
../source/tot_info.exe  < ../inputs/universe/test165.inc > ../originals/t387
echo ">>>>>>>>running test 388"
../source/tot_info.exe  < ../inputs/universe/test166.inc > ../originals/t388
echo ">>>>>>>>running test 389"
../source/tot_info.exe  < ../inputs/universe/test167.inc > ../originals/t389
echo ">>>>>>>>running test 390"
../source/tot_info.exe  < ../inputs/universe/test168.inc > ../originals/t390
echo ">>>>>>>>running test 391"
../source/tot_info.exe  < ../inputs/universe/test169.inc > ../originals/t391
echo ">>>>>>>>running test 392"
../source/tot_info.exe  < ../inputs/universe/test170.inc > ../originals/t392
echo ">>>>>>>>running test 393"
../source/tot_info.exe  < ../inputs/universe/test171.inc > ../originals/t393
echo ">>>>>>>>running test 394"
../source/tot_info.exe  < ../inputs/universe/test172.inc > ../originals/t394
echo ">>>>>>>>running test 395"
../source/tot_info.exe  < ../inputs/universe/test173.inc > ../originals/t395
echo ">>>>>>>>running test 396"
../source/tot_info.exe  < ../inputs/universe/test174.inc > ../originals/t396
echo ">>>>>>>>running test 397"
../source/tot_info.exe  < ../inputs/universe/test175.inc > ../originals/t397
echo ">>>>>>>>running test 398"
../source/tot_info.exe  < ../inputs/universe/test176.inc > ../originals/t398
echo ">>>>>>>>running test 399"
../source/tot_info.exe  < ../inputs/universe/test177.inc > ../originals/t399
echo ">>>>>>>>running test 400"
../source/tot_info.exe  < ../inputs/universe/test178.inc > ../originals/t400
echo ">>>>>>>>running test 401"
../source/tot_info.exe  < ../inputs/universe/test179.inc > ../originals/t401
echo ">>>>>>>>running test 402"
../source/tot_info.exe  < ../inputs/universe/test180.inc > ../originals/t402
echo ">>>>>>>>running test 403"
../source/tot_info.exe  < ../inputs/universe/test181.inc > ../originals/t403
echo ">>>>>>>>running test 404"
../source/tot_info.exe  < ../inputs/universe/test182.inc > ../originals/t404
echo ">>>>>>>>running test 405"
../source/tot_info.exe  < ../inputs/universe/test183.inc > ../originals/t405
echo ">>>>>>>>running test 406"
../source/tot_info.exe  < ../inputs/universe/test184.inc > ../originals/t406
echo ">>>>>>>>running test 407"
../source/tot_info.exe  < ../inputs/universe/test185.inc > ../originals/t407
echo ">>>>>>>>running test 408"
../source/tot_info.exe  < ../inputs/universe/test186.inc > ../originals/t408
echo ">>>>>>>>running test 409"
../source/tot_info.exe  < ../inputs/universe/test187.inc > ../originals/t409
echo ">>>>>>>>running test 410"
../source/tot_info.exe  < ../inputs/universe/test188.inc > ../originals/t410
echo ">>>>>>>>running test 411"
../source/tot_info.exe  < ../inputs/universe/test189.inc > ../originals/t411
echo ">>>>>>>>running test 412"
../source/tot_info.exe  < ../inputs/universe/test190.inc > ../originals/t412
echo ">>>>>>>>running test 413"
../source/tot_info.exe  < ../inputs/universe/test191.inc > ../originals/t413
echo ">>>>>>>>running test 414"
../source/tot_info.exe  < ../inputs/universe/test192.inc > ../originals/t414
echo ">>>>>>>>running test 415"
../source/tot_info.exe  < ../inputs/universe/test193.inc > ../originals/t415
echo ">>>>>>>>running test 416"
../source/tot_info.exe  < ../inputs/universe/test194.inc > ../originals/t416
echo ">>>>>>>>running test 417"
../source/tot_info.exe  < ../inputs/universe/test195.inc > ../originals/t417
echo ">>>>>>>>running test 418"
../source/tot_info.exe  < ../inputs/universe/test196.inc > ../originals/t418
echo ">>>>>>>>running test 419"
../source/tot_info.exe  < ../inputs/universe/test197.inc > ../originals/t419
echo ">>>>>>>>running test 420"
../source/tot_info.exe  < ../inputs/universe/test198.inc > ../originals/t420
echo ">>>>>>>>running test 421"
../source/tot_info.exe  < ../inputs/universe/test199.inc > ../originals/t421
echo ">>>>>>>>running test 422"
../source/tot_info.exe  < ../inputs/universe/test300.inc > ../originals/t422
echo ">>>>>>>>running test 423"
../source/tot_info.exe  < ../inputs/universe/test301.inc > ../originals/t423
echo ">>>>>>>>running test 424"
../source/tot_info.exe  < ../inputs/universe/test302.inc > ../originals/t424
echo ">>>>>>>>running test 425"
../source/tot_info.exe  < ../inputs/universe/test303.inc > ../originals/t425
echo ">>>>>>>>running test 426"
../source/tot_info.exe  < ../inputs/universe/test304.inc > ../originals/t426
echo ">>>>>>>>running test 427"
../source/tot_info.exe  < ../inputs/universe/test305.inc > ../originals/t427
echo ">>>>>>>>running test 428"
../source/tot_info.exe  < ../inputs/universe/test306.inc > ../originals/t428
echo ">>>>>>>>running test 429"
../source/tot_info.exe  < ../inputs/universe/test307.inc > ../originals/t429
echo ">>>>>>>>running test 430"
../source/tot_info.exe  < ../inputs/universe/test308.inc > ../originals/t430
echo ">>>>>>>>running test 431"
../source/tot_info.exe  < ../inputs/universe/test309.inc > ../originals/t431
echo ">>>>>>>>running test 432"
../source/tot_info.exe  < ../inputs/universe/test310.inc > ../originals/t432
echo ">>>>>>>>running test 433"
../source/tot_info.exe  < ../inputs/universe/test311.inc > ../originals/t433
echo ">>>>>>>>running test 434"
../source/tot_info.exe  < ../inputs/universe/test312.inc > ../originals/t434
echo ">>>>>>>>running test 435"
../source/tot_info.exe  < ../inputs/universe/test313.inc > ../originals/t435
echo ">>>>>>>>running test 436"
../source/tot_info.exe  < ../inputs/universe/test314.inc > ../originals/t436
echo ">>>>>>>>running test 437"
../source/tot_info.exe  < ../inputs/universe/test315.inc > ../originals/t437
echo ">>>>>>>>running test 438"
../source/tot_info.exe  < ../inputs/universe/test316.inc > ../originals/t438
echo ">>>>>>>>running test 439"
../source/tot_info.exe  < ../inputs/universe/test317.inc > ../originals/t439
echo ">>>>>>>>running test 440"
../source/tot_info.exe  < ../inputs/universe/test318.inc > ../originals/t440
echo ">>>>>>>>running test 441"
../source/tot_info.exe  < ../inputs/universe/test319.inc > ../originals/t441
echo ">>>>>>>>running test 442"
../source/tot_info.exe  < ../inputs/universe/test320.inc > ../originals/t442
echo ">>>>>>>>running test 443"
../source/tot_info.exe  < ../inputs/universe/test321.inc > ../originals/t443
echo ">>>>>>>>running test 444"
../source/tot_info.exe  < ../inputs/universe/test322.inc > ../originals/t444
echo ">>>>>>>>running test 445"
../source/tot_info.exe  < ../inputs/universe/test323.inc > ../originals/t445
echo ">>>>>>>>running test 446"
../source/tot_info.exe  < ../inputs/universe/test324.inc > ../originals/t446
echo ">>>>>>>>running test 447"
../source/tot_info.exe  < ../inputs/universe/test325.inc > ../originals/t447
echo ">>>>>>>>running test 448"
../source/tot_info.exe  < ../inputs/universe/test326.inc > ../originals/t448
echo ">>>>>>>>running test 449"
../source/tot_info.exe  < ../inputs/universe/test327.inc > ../originals/t449
echo ">>>>>>>>running test 450"
../source/tot_info.exe  < ../inputs/universe/test328.inc > ../originals/t450
echo ">>>>>>>>running test 451"
../source/tot_info.exe  < ../inputs/universe/test329.inc > ../originals/t451
echo ">>>>>>>>running test 452"
../source/tot_info.exe  < ../inputs/universe/test331.inc > ../originals/t452
echo ">>>>>>>>running test 453"
../source/tot_info.exe  < ../inputs/universe/test332.inc > ../originals/t453
echo ">>>>>>>>running test 454"
../source/tot_info.exe  < ../inputs/universe/test333.inc > ../originals/t454
echo ">>>>>>>>running test 455"
../source/tot_info.exe  < ../inputs/universe/test334.inc > ../originals/t455
echo ">>>>>>>>running test 456"
../source/tot_info.exe  < ../inputs/universe/test335.inc > ../originals/t456
echo ">>>>>>>>running test 457"
../source/tot_info.exe  < ../inputs/universe/test336.inc > ../originals/t457
echo ">>>>>>>>running test 458"
../source/tot_info.exe  < ../inputs/universe/test337.inc > ../originals/t458
echo ">>>>>>>>running test 459"
../source/tot_info.exe  < ../inputs/universe/test338.inc > ../originals/t459
echo ">>>>>>>>running test 460"
../source/tot_info.exe  < ../inputs/universe/test339.inc > ../originals/t460
echo ">>>>>>>>running test 461"
../source/tot_info.exe  < ../inputs/universe/test340.inc > ../originals/t461
echo ">>>>>>>>running test 462"
../source/tot_info.exe  < ../inputs/universe/test341.inc > ../originals/t462
echo ">>>>>>>>running test 463"
../source/tot_info.exe  < ../inputs/universe/test342.inc > ../originals/t463
echo ">>>>>>>>running test 464"
../source/tot_info.exe  < ../inputs/universe/test343.inc > ../originals/t464
echo ">>>>>>>>running test 465"
../source/tot_info.exe  < ../inputs/universe/test344.inc > ../originals/t465
echo ">>>>>>>>running test 466"
../source/tot_info.exe  < ../inputs/universe/test345.inc > ../originals/t466
echo ">>>>>>>>running test 467"
../source/tot_info.exe  < ../inputs/universe/test346.inc > ../originals/t467
echo ">>>>>>>>running test 468"
../source/tot_info.exe  < ../inputs/universe/test347.inc > ../originals/t468
echo ">>>>>>>>running test 469"
../source/tot_info.exe  < ../inputs/universe/test348.inc > ../originals/t469
echo ">>>>>>>>running test 470"
../source/tot_info.exe  < ../inputs/universe/test349.inc > ../originals/t470
echo ">>>>>>>>running test 471"
../source/tot_info.exe  < ../inputs/universe/test350.inc > ../originals/t471
echo ">>>>>>>>running test 472"
../source/tot_info.exe  < ../inputs/universe/test351.inc > ../originals/t472
echo ">>>>>>>>running test 473"
../source/tot_info.exe  < ../inputs/universe/test352.inc > ../originals/t473
echo ">>>>>>>>running test 474"
../source/tot_info.exe  < ../inputs/universe/test353.inc > ../originals/t474
echo ">>>>>>>>running test 475"
../source/tot_info.exe  < ../inputs/universe/test354.inc > ../originals/t475
echo ">>>>>>>>running test 476"
../source/tot_info.exe  < ../inputs/universe/test355.inc > ../originals/t476
echo ">>>>>>>>running test 477"
../source/tot_info.exe  < ../inputs/universe/test356.inc > ../originals/t477
echo ">>>>>>>>running test 478"
../source/tot_info.exe  < ../inputs/universe/test357.inc > ../originals/t478
echo ">>>>>>>>running test 479"
../source/tot_info.exe  < ../inputs/universe/test358.inc > ../originals/t479
echo ">>>>>>>>running test 480"
../source/tot_info.exe  < ../inputs/universe/test359.inc > ../originals/t480
echo ">>>>>>>>running test 481"
../source/tot_info.exe  < ../inputs/universe/test361.inc > ../originals/t481
echo ">>>>>>>>running test 482"
../source/tot_info.exe  < ../inputs/universe/test362.inc > ../originals/t482
echo ">>>>>>>>running test 483"
../source/tot_info.exe  < ../inputs/universe/test363.inc > ../originals/t483
echo ">>>>>>>>running test 484"
../source/tot_info.exe  < ../inputs/universe/test364.inc > ../originals/t484
echo ">>>>>>>>running test 485"
../source/tot_info.exe  < ../inputs/universe/test365.inc > ../originals/t485
echo ">>>>>>>>running test 486"
../source/tot_info.exe  < ../inputs/universe/test366.inc > ../originals/t486
echo ">>>>>>>>running test 487"
../source/tot_info.exe  < ../inputs/universe/test367.inc > ../originals/t487
echo ">>>>>>>>running test 488"
../source/tot_info.exe  < ../inputs/universe/test368.inc > ../originals/t488
echo ">>>>>>>>running test 489"
../source/tot_info.exe  < ../inputs/universe/test369.inc > ../originals/t489
echo ">>>>>>>>running test 490"
../source/tot_info.exe  < ../inputs/universe/test370.inc > ../originals/t490
echo ">>>>>>>>running test 491"
../source/tot_info.exe  < ../inputs/universe/test371.inc > ../originals/t491
echo ">>>>>>>>running test 492"
../source/tot_info.exe  < ../inputs/universe/test372.inc > ../originals/t492
echo ">>>>>>>>running test 493"
../source/tot_info.exe  < ../inputs/universe/test373.inc > ../originals/t493
echo ">>>>>>>>running test 494"
../source/tot_info.exe  < ../inputs/universe/test374.inc > ../originals/t494
echo ">>>>>>>>running test 495"
../source/tot_info.exe  < ../inputs/universe/test375.inc > ../originals/t495
echo ">>>>>>>>running test 496"
../source/tot_info.exe  < ../inputs/universe/test376.inc > ../originals/t496
echo ">>>>>>>>running test 497"
../source/tot_info.exe  < ../inputs/universe/test377.inc > ../originals/t497
echo ">>>>>>>>running test 498"
../source/tot_info.exe  < ../inputs/universe/test378.inc > ../originals/t498
echo ">>>>>>>>running test 499"
../source/tot_info.exe  < ../inputs/universe/test379.inc > ../originals/t499
echo ">>>>>>>>running test 500"
../source/tot_info.exe  < ../inputs/universe/test380.inc > ../originals/t500
echo ">>>>>>>>running test 501"
../source/tot_info.exe  < ../inputs/universe/test381.inc > ../originals/t501
echo ">>>>>>>>running test 502"
../source/tot_info.exe  < ../inputs/universe/test382.inc > ../originals/t502
echo ">>>>>>>>running test 503"
../source/tot_info.exe  < ../inputs/universe/test383.inc > ../originals/t503
echo ">>>>>>>>running test 504"
../source/tot_info.exe  < ../inputs/universe/test384.inc > ../originals/t504
echo ">>>>>>>>running test 505"
../source/tot_info.exe  < ../inputs/universe/test385.inc > ../originals/t505
echo ">>>>>>>>running test 506"
../source/tot_info.exe  < ../inputs/universe/test386.inc > ../originals/t506
echo ">>>>>>>>running test 507"
../source/tot_info.exe  < ../inputs/universe/test387.inc > ../originals/t507
echo ">>>>>>>>running test 508"
../source/tot_info.exe  < ../inputs/universe/test388.inc > ../originals/t508
echo ">>>>>>>>running test 509"
../source/tot_info.exe  < ../inputs/universe/test390.inc > ../originals/t509
echo ">>>>>>>>running test 510"
../source/tot_info.exe  < ../inputs/universe/test391.inc > ../originals/t510
echo ">>>>>>>>running test 511"
../source/tot_info.exe  < ../inputs/universe/test392.inc > ../originals/t511
echo ">>>>>>>>running test 512"
../source/tot_info.exe  < ../inputs/universe/test393.inc > ../originals/t512
echo ">>>>>>>>running test 513"
../source/tot_info.exe  < ../inputs/universe/test394.inc > ../originals/t513
echo ">>>>>>>>running test 514"
../source/tot_info.exe  < ../inputs/universe/test395.inc > ../originals/t514
echo ">>>>>>>>running test 515"
../source/tot_info.exe  < ../inputs/universe/test396.inc > ../originals/t515
echo ">>>>>>>>running test 516"
../source/tot_info.exe  < ../inputs/universe/test397.inc > ../originals/t516
echo ">>>>>>>>running test 517"
../source/tot_info.exe  < ../inputs/universe/test398.inc > ../originals/t517
echo ">>>>>>>>running test 518"
../source/tot_info.exe  < ../inputs/universe/test399.inc > ../originals/t518
echo ">>>>>>>>running test 519"
../source/tot_info.exe  < ../inputs/universe/test400.inc > ../originals/t519
echo ">>>>>>>>running test 520"
../source/tot_info.exe  < ../inputs/universe/test401.inc > ../originals/t520
echo ">>>>>>>>running test 521"
../source/tot_info.exe  < ../inputs/universe/test402.inc > ../originals/t521
echo ">>>>>>>>running test 522"
../source/tot_info.exe  < ../inputs/universe/test403.inc > ../originals/t522
echo ">>>>>>>>running test 523"
../source/tot_info.exe  < ../inputs/universe/test404.inc > ../originals/t523
echo ">>>>>>>>running test 524"
../source/tot_info.exe  < ../inputs/universe/test405.inc > ../originals/t524
echo ">>>>>>>>running test 525"
../source/tot_info.exe  < ../inputs/universe/test406.inc > ../originals/t525
echo ">>>>>>>>running test 526"
../source/tot_info.exe  < ../inputs/universe/test407.inc > ../originals/t526
echo ">>>>>>>>running test 527"
../source/tot_info.exe  < ../inputs/universe/test408.inc > ../originals/t527
echo ">>>>>>>>running test 528"
../source/tot_info.exe  < ../inputs/universe/test409.inc > ../originals/t528
echo ">>>>>>>>running test 529"
../source/tot_info.exe  < ../inputs/universe/test410.inc > ../originals/t529
echo ">>>>>>>>running test 530"
../source/tot_info.exe  < ../inputs/universe/tst21.mat > ../originals/t530
echo ">>>>>>>>running test 531"
../source/tot_info.exe  < ../inputs/universe/tst22.mat > ../originals/t531
echo ">>>>>>>>running test 532"
../source/tot_info.exe  < ../inputs/universe/tst23.mat > ../originals/t532
echo ">>>>>>>>running test 533"
../source/tot_info.exe  < ../inputs/universe/tst24.mat > ../originals/t533
echo ">>>>>>>>running test 534"
../source/tot_info.exe  < ../inputs/universe/tst25.mat > ../originals/t534
echo ">>>>>>>>running test 535"
../source/tot_info.exe  < ../inputs/universe/tst26.mat > ../originals/t535
echo ">>>>>>>>running test 536"
../source/tot_info.exe  < ../inputs/universe/tst27.mat > ../originals/t536
echo ">>>>>>>>running test 537"
../source/tot_info.exe  < ../inputs/universe/tst28.mat > ../originals/t537
echo ">>>>>>>>running test 538"
../source/tot_info.exe  < ../inputs/universe/tst2question.mat > ../originals/t538
echo ">>>>>>>>running test 539"
../source/tot_info.exe  < ../inputs/universe/tst2rtangle.mat > ../originals/t539
echo ">>>>>>>>running test 540"
../source/tot_info.exe  < ../inputs/universe/tst2=.mat > ../originals/t540
echo ">>>>>>>>running test 541"
../source/tot_info.exe  < ../inputs/universe/tst2:.mat > ../originals/t541
echo ">>>>>>>>running test 542"
../source/tot_info.exe  < ../inputs/universe/tst2g.mat > ../originals/t542
echo ">>>>>>>>running test 543"
../source/tot_info.exe  < ../inputs/universe/tst2@.mat > ../originals/t543
echo ">>>>>>>>running test 544"
../source/tot_info.exe  < ../inputs/universe/tst2A.mat > ../originals/t544
echo ">>>>>>>>running test 545"
../source/tot_info.exe  < ../inputs/universe/tst2B.mat > ../originals/t545
echo ">>>>>>>>running test 546"
../source/tot_info.exe  < ../inputs/universe/tst2D.mat > ../originals/t546
echo ">>>>>>>>running test 547"
../source/tot_info.exe  < ../inputs/universe/tst2E.mat > ../originals/t547
echo ">>>>>>>>running test 548"
../source/tot_info.exe  < ../inputs/universe/tst2f.mat > ../originals/t548
echo ">>>>>>>>running test 549"
../source/tot_info.exe  < ../inputs/universe/tst2D.mat > ../originals/t549
echo ">>>>>>>>running test 550"
../source/tot_info.exe  < ../inputs/universe/jkAAA.mat > ../originals/t550
echo ">>>>>>>>running test 551"
../source/tot_info.exe  < ../inputs/universe/jkAAB.mat > ../originals/t551
echo ">>>>>>>>running test 552"
../source/tot_info.exe  < ../inputs/universe/jkAAC.mat > ../originals/t552
echo ">>>>>>>>running test 553"
../source/tot_info.exe  < ../inputs/universe/jkAAD.mat > ../originals/t553
echo ">>>>>>>>running test 554"
../source/tot_info.exe  < ../inputs/universe/jkAAE.mat > ../originals/t554
echo ">>>>>>>>running test 555"
../source/tot_info.exe  < ../inputs/universe/jkAAF.mat > ../originals/t555
echo ">>>>>>>>running test 556"
../source/tot_info.exe  < ../inputs/universe/jkAAG.mat > ../originals/t556
echo ">>>>>>>>running test 557"
../source/tot_info.exe  < ../inputs/universe/jkAAH.mat > ../originals/t557
echo ">>>>>>>>running test 558"
../source/tot_info.exe  < ../inputs/universe/jkAAI.mat > ../originals/t558
echo ">>>>>>>>running test 559"
../source/tot_info.exe  < ../inputs/universe/jkAAJ.mat > ../originals/t559
echo ">>>>>>>>running test 560"
../source/tot_info.exe  < ../inputs/universe/jkAFa.mat > ../originals/t560
echo ">>>>>>>>running test 561"
../source/tot_info.exe  < ../inputs/universe/jkAFb.mat > ../originals/t561
echo ">>>>>>>>running test 562"
../source/tot_info.exe  < ../inputs/universe/jkAFc.mat > ../originals/t562
echo ">>>>>>>>running test 563"
../source/tot_info.exe  < ../inputs/universe/jkAFd.mat > ../originals/t563
echo ">>>>>>>>running test 564"
../source/tot_info.exe  < ../inputs/universe/jkAFe.mat > ../originals/t564
echo ">>>>>>>>running test 565"
../source/tot_info.exe  < ../inputs/universe/jkAFf.mat > ../originals/t565
echo ">>>>>>>>running test 566"
../source/tot_info.exe  < ../inputs/universe/jkAFg.mat > ../originals/t566
echo ">>>>>>>>running test 567"
../source/tot_info.exe  < ../inputs/universe/jkAFh.mat > ../originals/t567
echo ">>>>>>>>running test 568"
../source/tot_info.exe  < ../inputs/universe/jkAFi.mat > ../originals/t568
echo ">>>>>>>>running test 569"
../source/tot_info.exe  < ../inputs/universe/jkAEI.mat > ../originals/t569
echo ">>>>>>>>running test 570"
../source/tot_info.exe  < ../inputs/universe/jkAEJ.mat > ../originals/t570
echo ">>>>>>>>running test 571"
../source/tot_info.exe  < ../inputs/universe/jkAEK.mat > ../originals/t571
echo ">>>>>>>>running test 572"
../source/tot_info.exe  < ../inputs/universe/jkAEL.mat > ../originals/t572
echo ">>>>>>>>running test 573"
../source/tot_info.exe  < ../inputs/universe/jkAEM.mat > ../originals/t573
echo ">>>>>>>>running test 574"
../source/tot_info.exe  < ../inputs/universe/jkAEN.mat > ../originals/t574
echo ">>>>>>>>running test 575"
../source/tot_info.exe  < ../inputs/universe/jkAEO.mat > ../originals/t575
echo ">>>>>>>>running test 576"
../source/tot_info.exe  < ../inputs/universe/jkAEP.mat > ../originals/t576
echo ">>>>>>>>running test 577"
../source/tot_info.exe  < ../inputs/universe/jkAEQ.mat > ../originals/t577
echo ">>>>>>>>running test 578"
../source/tot_info.exe  < ../inputs/universe/jkAER.mat > ../originals/t578
echo ">>>>>>>>running test 579"
../source/tot_info.exe  < ../inputs/universe/jkAES.mat > ../originals/t579
echo ">>>>>>>>running test 580"
../source/tot_info.exe  < ../inputs/universe/jkAET.mat > ../originals/t580
echo ">>>>>>>>running test 581"
../source/tot_info.exe  < ../inputs/universe/jkAEU.mat > ../originals/t581
echo ">>>>>>>>running test 582"
../source/tot_info.exe  < ../inputs/universe/jkAEV.mat > ../originals/t582
echo ">>>>>>>>running test 583"
../source/tot_info.exe  < ../inputs/universe/jkAEW.mat > ../originals/t583
echo ">>>>>>>>running test 584"
../source/tot_info.exe  < ../inputs/universe/jkAEX.mat > ../originals/t584
echo ">>>>>>>>running test 585"
../source/tot_info.exe  < ../inputs/universe/jkAEY.mat > ../originals/t585
echo ">>>>>>>>running test 586"
../source/tot_info.exe  < ../inputs/universe/jkAEZ.mat > ../originals/t586
echo ">>>>>>>>running test 587"
../source/tot_info.exe  < ../inputs/universe/jkAE[.mat > ../originals/t587
echo ">>>>>>>>running test 588"
../source/tot_info.exe  < ../inputs/universe/jkAE].mat > ../originals/t588
echo ">>>>>>>>running test 589"
../source/tot_info.exe  < ../inputs/universe/jkAE_.mat > ../originals/t589
echo ">>>>>>>>running test 590"
../source/tot_info.exe  < ../inputs/universe/jkAEa.mat > ../originals/t590
echo ">>>>>>>>running test 591"
../source/tot_info.exe  < ../inputs/universe/jkAEb.mat > ../originals/t591
echo ">>>>>>>>running test 592"
../source/tot_info.exe  < ../inputs/universe/jkAEc.mat > ../originals/t592
echo ">>>>>>>>running test 593"
../source/tot_info.exe  < ../inputs/universe/jkAEd.mat > ../originals/t593
echo ">>>>>>>>running test 594"
../source/tot_info.exe  < ../inputs/universe/jkAEe.mat > ../originals/t594
echo ">>>>>>>>running test 595"
../source/tot_info.exe  < ../inputs/universe/jkAEf.mat > ../originals/t595
echo ">>>>>>>>running test 596"
../source/tot_info.exe  < ../inputs/universe/jkAEg.mat > ../originals/t596
echo ">>>>>>>>running test 597"
../source/tot_info.exe  < ../inputs/universe/jkAEh.mat > ../originals/t597
echo ">>>>>>>>running test 598"
../source/tot_info.exe  < ../inputs/universe/jkAEi.mat > ../originals/t598
echo ">>>>>>>>running test 599"
../source/tot_info.exe  < ../inputs/universe/jkAEj.mat > ../originals/t599
echo ">>>>>>>>running test 600"
../source/tot_info.exe  < ../inputs/universe/jkAEk.mat > ../originals/t600
echo ">>>>>>>>running test 601"
../source/tot_info.exe  < ../inputs/universe/jkAEl.mat > ../originals/t601
echo ">>>>>>>>running test 602"
../source/tot_info.exe  < ../inputs/universe/jkAEm.mat > ../originals/t602
echo ">>>>>>>>running test 603"
../source/tot_info.exe  < ../inputs/universe/jkAEn.mat > ../originals/t603
echo ">>>>>>>>running test 604"
../source/tot_info.exe  < ../inputs/universe/jkAEo.mat > ../originals/t604
echo ">>>>>>>>running test 605"
../source/tot_info.exe  < ../inputs/universe/jkAEp.mat > ../originals/t605
echo ">>>>>>>>running test 606"
../source/tot_info.exe  < ../inputs/universe/jkAEq.mat > ../originals/t606
echo ">>>>>>>>running test 607"
../source/tot_info.exe  < ../inputs/universe/jkAEr.mat > ../originals/t607
echo ">>>>>>>>running test 608"
../source/tot_info.exe  < ../inputs/universe/jkAEs.mat > ../originals/t608
echo ">>>>>>>>running test 609"
../source/tot_info.exe  < ../inputs/universe/jkAEt.mat > ../originals/t609
echo ">>>>>>>>running test 610"
../source/tot_info.exe  < ../inputs/universe/jkAEu.mat > ../originals/t610
echo ">>>>>>>>running test 611"
../source/tot_info.exe  < ../inputs/universe/jkAEv.mat > ../originals/t611
echo ">>>>>>>>running test 612"
../source/tot_info.exe  < ../inputs/universe/jkAEw.mat > ../originals/t612
echo ">>>>>>>>running test 613"
../source/tot_info.exe  < ../inputs/universe/jkAEx.mat > ../originals/t613
echo ">>>>>>>>running test 614"
../source/tot_info.exe  < ../inputs/universe/jkAEy.mat > ../originals/t614
echo ">>>>>>>>running test 615"
../source/tot_info.exe  < ../inputs/universe/jkAFA.mat > ../originals/t615
echo ">>>>>>>>running test 616"
../source/tot_info.exe  < ../inputs/universe/jkAFB.mat > ../originals/t616
echo ">>>>>>>>running test 617"
../source/tot_info.exe  < ../inputs/universe/jkAFC.mat > ../originals/t617
echo ">>>>>>>>running test 618"
../source/tot_info.exe  < ../inputs/universe/jkAFD.mat > ../originals/t618
echo ">>>>>>>>running test 619"
../source/tot_info.exe  < ../inputs/universe/jkAFE.mat > ../originals/t619
echo ">>>>>>>>running test 620"
../source/tot_info.exe  < ../inputs/universe/jkAFF.mat > ../originals/t620
echo ">>>>>>>>running test 621"
../source/tot_info.exe  < ../inputs/universe/jkAFG.mat > ../originals/t621
echo ">>>>>>>>running test 622"
../source/tot_info.exe  < ../inputs/universe/jkAFH.mat > ../originals/t622
echo ">>>>>>>>running test 623"
../source/tot_info.exe  < ../inputs/universe/jkAFI.mat > ../originals/t623
echo ">>>>>>>>running test 624"
../source/tot_info.exe  < ../inputs/universe/jkAFJ.mat > ../originals/t624
echo ">>>>>>>>running test 625"
../source/tot_info.exe  < ../inputs/universe/jkAFK.mat > ../originals/t625
echo ">>>>>>>>running test 626"
../source/tot_info.exe  < ../inputs/universe/jkAFL.mat > ../originals/t626
echo ">>>>>>>>running test 627"
../source/tot_info.exe  < ../inputs/universe/jkAFM.mat > ../originals/t627
echo ">>>>>>>>running test 628"
../source/tot_info.exe  < ../inputs/universe/jkAFN.mat > ../originals/t628
echo ">>>>>>>>running test 629"
../source/tot_info.exe  < ../inputs/universe/jkAFO.mat > ../originals/t629
echo ">>>>>>>>running test 630"
../source/tot_info.exe  < ../inputs/universe/jkAFP.mat > ../originals/t630
echo ">>>>>>>>running test 631"
../source/tot_info.exe  < ../inputs/universe/jkAFQ.mat > ../originals/t631
echo ">>>>>>>>running test 632"
../source/tot_info.exe  < ../inputs/universe/jkAFR.mat > ../originals/t632
echo ">>>>>>>>running test 633"
../source/tot_info.exe  < ../inputs/universe/jkAFS.mat > ../originals/t633
echo ">>>>>>>>running test 634"
../source/tot_info.exe  < ../inputs/universe/jkAFT.mat > ../originals/t634
echo ">>>>>>>>running test 635"
../source/tot_info.exe  < ../inputs/universe/jkAFU.mat > ../originals/t635
echo ">>>>>>>>running test 636"
../source/tot_info.exe  < ../inputs/universe/jkAFV.mat > ../originals/t636
echo ">>>>>>>>running test 637"
../source/tot_info.exe  < ../inputs/universe/jkAFW.mat > ../originals/t637
echo ">>>>>>>>running test 638"
../source/tot_info.exe  < ../inputs/universe/jkAFX.mat > ../originals/t638
echo ">>>>>>>>running test 639"
../source/tot_info.exe  < ../inputs/universe/jkAFY.mat > ../originals/t639
echo ">>>>>>>>running test 640"
../source/tot_info.exe  < ../inputs/universe/jkAFZ.mat > ../originals/t640
echo ">>>>>>>>running test 641"
../source/tot_info.exe  < ../inputs/universe/jkAF[.mat > ../originals/t641
echo ">>>>>>>>running test 642"
../source/tot_info.exe  < ../inputs/universe/jkAF].mat > ../originals/t642
echo ">>>>>>>>running test 643"
../source/tot_info.exe  < ../inputs/universe/jkAFhh.mat > ../originals/t643
echo ">>>>>>>>running test 644"
../source/tot_info.exe  < ../inputs/universe/jkAF_.mat > ../originals/t644
echo ">>>>>>>>running test 645"
../source/tot_info.exe  < ../inputs/universe/jkACk.mat > ../originals/t645
echo ">>>>>>>>running test 646"
../source/tot_info.exe  < ../inputs/universe/jkACl.mat > ../originals/t646
echo ">>>>>>>>running test 647"
../source/tot_info.exe  < ../inputs/universe/jkACm.mat > ../originals/t647
echo ">>>>>>>>running test 648"
../source/tot_info.exe  < ../inputs/universe/jkACn.mat > ../originals/t648
echo ">>>>>>>>running test 649"
../source/tot_info.exe  < ../inputs/universe/jkACo.mat > ../originals/t649
echo ">>>>>>>>running test 650"
../source/tot_info.exe  < ../inputs/universe/jkACp.mat > ../originals/t650
echo ">>>>>>>>running test 651"
../source/tot_info.exe  < ../inputs/universe/jkACq.mat > ../originals/t651
echo ">>>>>>>>running test 652"
../source/tot_info.exe  < ../inputs/universe/jkACr.mat > ../originals/t652
echo ">>>>>>>>running test 653"
../source/tot_info.exe  < ../inputs/universe/jkACs.mat > ../originals/t653
echo ">>>>>>>>running test 654"
../source/tot_info.exe  < ../inputs/universe/jkACt.mat > ../originals/t654
echo ">>>>>>>>running test 655"
../source/tot_info.exe  < ../inputs/universe/jkACu.mat > ../originals/t655
echo ">>>>>>>>running test 656"
../source/tot_info.exe  < ../inputs/universe/jkACv.mat > ../originals/t656
echo ">>>>>>>>running test 657"
../source/tot_info.exe  < ../inputs/universe/jkACw.mat > ../originals/t657
echo ">>>>>>>>running test 658"
../source/tot_info.exe  < ../inputs/universe/jkACx.mat > ../originals/t658
echo ">>>>>>>>running test 659"
../source/tot_info.exe  < ../inputs/universe/jkACy.mat > ../originals/t659
echo ">>>>>>>>running test 660"
../source/tot_info.exe  < ../inputs/universe/jkADA.mat > ../originals/t660
echo ">>>>>>>>running test 661"
../source/tot_info.exe  < ../inputs/universe/jkADB.mat > ../originals/t661
echo ">>>>>>>>running test 662"
../source/tot_info.exe  < ../inputs/universe/jkADC.mat > ../originals/t662
echo ">>>>>>>>running test 663"
../source/tot_info.exe  < ../inputs/universe/jkADD.mat > ../originals/t663
echo ">>>>>>>>running test 664"
../source/tot_info.exe  < ../inputs/universe/jkADE.mat > ../originals/t664
echo ">>>>>>>>running test 665"
../source/tot_info.exe  < ../inputs/universe/jkADF.mat > ../originals/t665
echo ">>>>>>>>running test 666"
../source/tot_info.exe  < ../inputs/universe/jkADG.mat > ../originals/t666
echo ">>>>>>>>running test 667"
../source/tot_info.exe  < ../inputs/universe/jkADH.mat > ../originals/t667
echo ">>>>>>>>running test 668"
../source/tot_info.exe  < ../inputs/universe/jkADI.mat > ../originals/t668
echo ">>>>>>>>running test 669"
../source/tot_info.exe  < ../inputs/universe/jkADJ.mat > ../originals/t669
echo ">>>>>>>>running test 670"
../source/tot_info.exe  < ../inputs/universe/jkADK.mat > ../originals/t670
echo ">>>>>>>>running test 671"
../source/tot_info.exe  < ../inputs/universe/jkADL.mat > ../originals/t671
echo ">>>>>>>>running test 672"
../source/tot_info.exe  < ../inputs/universe/jkADM.mat > ../originals/t672
echo ">>>>>>>>running test 673"
../source/tot_info.exe  < ../inputs/universe/jkADN.mat > ../originals/t673
echo ">>>>>>>>running test 674"
../source/tot_info.exe  < ../inputs/universe/jkADO.mat > ../originals/t674
echo ">>>>>>>>running test 675"
../source/tot_info.exe  < ../inputs/universe/jkADP.mat > ../originals/t675
echo ">>>>>>>>running test 676"
../source/tot_info.exe  < ../inputs/universe/jkADQ.mat > ../originals/t676
echo ">>>>>>>>running test 677"
../source/tot_info.exe  < ../inputs/universe/jkADR.mat > ../originals/t677
echo ">>>>>>>>running test 678"
../source/tot_info.exe  < ../inputs/universe/jkADS.mat > ../originals/t678
echo ">>>>>>>>running test 679"
../source/tot_info.exe  < ../inputs/universe/jkADT.mat > ../originals/t679
echo ">>>>>>>>running test 680"
../source/tot_info.exe  < ../inputs/universe/jkADU.mat > ../originals/t680
echo ">>>>>>>>running test 681"
../source/tot_info.exe  < ../inputs/universe/jkADV.mat > ../originals/t681
echo ">>>>>>>>running test 682"
../source/tot_info.exe  < ../inputs/universe/jkADW.mat > ../originals/t682
echo ">>>>>>>>running test 683"
../source/tot_info.exe  < ../inputs/universe/jkADX.mat > ../originals/t683
echo ">>>>>>>>running test 684"
../source/tot_info.exe  < ../inputs/universe/jkADY.mat > ../originals/t684
echo ">>>>>>>>running test 685"
../source/tot_info.exe  < ../inputs/universe/jkADZ.mat > ../originals/t685
echo ">>>>>>>>running test 686"
../source/tot_info.exe  < ../inputs/universe/jkAD[.mat > ../originals/t686
echo ">>>>>>>>running test 687"
../source/tot_info.exe  < ../inputs/universe/jkAD].mat > ../originals/t687
echo ">>>>>>>>running test 688"
../source/tot_info.exe  < ../inputs/universe/jkADhh.mat > ../originals/t688
echo ">>>>>>>>running test 689"
../source/tot_info.exe  < ../inputs/universe/jkAD_.mat > ../originals/t689
echo ">>>>>>>>running test 690"
../source/tot_info.exe  < ../inputs/universe/jkADa.mat > ../originals/t690
echo ">>>>>>>>running test 691"
../source/tot_info.exe  < ../inputs/universe/jkADb.mat > ../originals/t691
echo ">>>>>>>>running test 692"
../source/tot_info.exe  < ../inputs/universe/jkAFi.mat > ../originals/t692
echo ">>>>>>>>running test 693"
../source/tot_info.exe  < ../inputs/universe/jkADd.mat > ../originals/t693
echo ">>>>>>>>running test 694"
../source/tot_info.exe  < ../inputs/universe/jkADe.mat > ../originals/t694
echo ">>>>>>>>running test 695"
../source/tot_info.exe  < ../inputs/universe/jkADf.mat > ../originals/t695
echo ">>>>>>>>running test 696"
../source/tot_info.exe  < ../inputs/universe/jkADg.mat > ../originals/t696
echo ">>>>>>>>running test 697"
../source/tot_info.exe  < ../inputs/universe/jkADh.mat > ../originals/t697
echo ">>>>>>>>running test 698"
../source/tot_info.exe  < ../inputs/universe/jkADi.mat > ../originals/t698
echo ">>>>>>>>running test 699"
../source/tot_info.exe  < ../inputs/universe/jkADj.mat > ../originals/t699
echo ">>>>>>>>running test 700"
../source/tot_info.exe  < ../inputs/universe/jkADk.mat > ../originals/t700
echo ">>>>>>>>running test 701"
../source/tot_info.exe  < ../inputs/universe/jkADl.mat > ../originals/t701
echo ">>>>>>>>running test 702"
../source/tot_info.exe  < ../inputs/universe/jkADm.mat > ../originals/t702
echo ">>>>>>>>running test 703"
../source/tot_info.exe  < ../inputs/universe/jkADn.mat > ../originals/t703
echo ">>>>>>>>running test 704"
../source/tot_info.exe  < ../inputs/universe/jkADo.mat > ../originals/t704
echo ">>>>>>>>running test 705"
../source/tot_info.exe  < ../inputs/universe/jkADp.mat > ../originals/t705
echo ">>>>>>>>running test 706"
../source/tot_info.exe  < ../inputs/universe/jkADq.mat > ../originals/t706
echo ">>>>>>>>running test 707"
../source/tot_info.exe  < ../inputs/universe/jkADr.mat > ../originals/t707
echo ">>>>>>>>running test 708"
../source/tot_info.exe  < ../inputs/universe/jkADs.mat > ../originals/t708
echo ">>>>>>>>running test 709"
../source/tot_info.exe  < ../inputs/universe/jkADt.mat > ../originals/t709
echo ">>>>>>>>running test 710"
../source/tot_info.exe  < ../inputs/universe/jkADu.mat > ../originals/t710
echo ">>>>>>>>running test 711"
../source/tot_info.exe  < ../inputs/universe/jkADv.mat > ../originals/t711
echo ">>>>>>>>running test 712"
../source/tot_info.exe  < ../inputs/universe/jkADw.mat > ../originals/t712
echo ">>>>>>>>running test 713"
../source/tot_info.exe  < ../inputs/universe/jkADx.mat > ../originals/t713
echo ">>>>>>>>running test 714"
../source/tot_info.exe  < ../inputs/universe/jkADy.mat > ../originals/t714
echo ">>>>>>>>running test 715"
../source/tot_info.exe  < ../inputs/universe/jkAEA.mat > ../originals/t715
echo ">>>>>>>>running test 716"
../source/tot_info.exe  < ../inputs/universe/jkAEB.mat > ../originals/t716
echo ">>>>>>>>running test 717"
../source/tot_info.exe  < ../inputs/universe/jkAEC.mat > ../originals/t717
echo ">>>>>>>>running test 718"
../source/tot_info.exe  < ../inputs/universe/jkAED.mat > ../originals/t718
echo ">>>>>>>>running test 719"
../source/tot_info.exe  < ../inputs/universe/jkAEE.mat > ../originals/t719
echo ">>>>>>>>running test 720"
../source/tot_info.exe  < ../inputs/universe/jkAEF.mat > ../originals/t720
echo ">>>>>>>>running test 721"
../source/tot_info.exe  < ../inputs/universe/jkAEG.mat > ../originals/t721
echo ">>>>>>>>running test 722"
../source/tot_info.exe  < ../inputs/universe/jkAEH.mat > ../originals/t722
echo ">>>>>>>>running test 723"
../source/tot_info.exe  < ../inputs/universe/jkABT.mat > ../originals/t723
echo ">>>>>>>>running test 724"
../source/tot_info.exe  < ../inputs/universe/jkABU.mat > ../originals/t724
echo ">>>>>>>>running test 725"
../source/tot_info.exe  < ../inputs/universe/jkABV.mat > ../originals/t725
echo ">>>>>>>>running test 726"
../source/tot_info.exe  < ../inputs/universe/jkABW.mat > ../originals/t726
echo ">>>>>>>>running test 727"
../source/tot_info.exe  < ../inputs/universe/jkABX.mat > ../originals/t727
echo ">>>>>>>>running test 728"
../source/tot_info.exe  < ../inputs/universe/jkABY.mat > ../originals/t728
echo ">>>>>>>>running test 729"
../source/tot_info.exe  < ../inputs/universe/jkABZ.mat > ../originals/t729
echo ">>>>>>>>running test 730"
../source/tot_info.exe  < ../inputs/universe/jkAB[.mat > ../originals/t730
echo ">>>>>>>>running test 731"
../source/tot_info.exe  < ../inputs/universe/jkAB].mat > ../originals/t731
echo ">>>>>>>>running test 732"
../source/tot_info.exe  < ../inputs/universe/jkAB_.mat > ../originals/t732
echo ">>>>>>>>running test 733"
../source/tot_info.exe  < ../inputs/universe/jkABa.mat > ../originals/t733
echo ">>>>>>>>running test 734"
../source/tot_info.exe  < ../inputs/universe/jkABb.mat > ../originals/t734
echo ">>>>>>>>running test 735"
../source/tot_info.exe  < ../inputs/universe/jkABc.mat > ../originals/t735
echo ">>>>>>>>running test 736"
../source/tot_info.exe  < ../inputs/universe/jkABd.mat > ../originals/t736
echo ">>>>>>>>running test 737"
../source/tot_info.exe  < ../inputs/universe/jkABe.mat > ../originals/t737
echo ">>>>>>>>running test 738"
../source/tot_info.exe  < ../inputs/universe/jkABf.mat > ../originals/t738
echo ">>>>>>>>running test 739"
../source/tot_info.exe  < ../inputs/universe/jkABg.mat > ../originals/t739
echo ">>>>>>>>running test 740"
../source/tot_info.exe  < ../inputs/universe/jkAB_.mat > ../originals/t740
echo ">>>>>>>>running test 741"
../source/tot_info.exe  < ../inputs/universe/jkABa.mat > ../originals/t741
echo ">>>>>>>>running test 742"
../source/tot_info.exe  < ../inputs/universe/jkABb.mat > ../originals/t742
echo ">>>>>>>>running test 743"
../source/tot_info.exe  < ../inputs/universe/jkABc.mat > ../originals/t743
echo ">>>>>>>>running test 744"
../source/tot_info.exe  < ../inputs/universe/jkABd.mat > ../originals/t744
echo ">>>>>>>>running test 745"
../source/tot_info.exe  < ../inputs/universe/jkABe.mat > ../originals/t745
echo ">>>>>>>>running test 746"
../source/tot_info.exe  < ../inputs/universe/jkABf.mat > ../originals/t746
echo ">>>>>>>>running test 747"
../source/tot_info.exe  < ../inputs/universe/jkABg.mat > ../originals/t747
echo ">>>>>>>>running test 748"
../source/tot_info.exe  < ../inputs/universe/jkABh.mat > ../originals/t748
echo ">>>>>>>>running test 749"
../source/tot_info.exe  < ../inputs/universe/jkABi.mat > ../originals/t749
echo ">>>>>>>>running test 750"
../source/tot_info.exe  < ../inputs/universe/jkABj.mat > ../originals/t750
echo ">>>>>>>>running test 751"
../source/tot_info.exe  < ../inputs/universe/jkABk.mat > ../originals/t751
echo ">>>>>>>>running test 752"
../source/tot_info.exe  < ../inputs/universe/jkABl.mat > ../originals/t752
echo ">>>>>>>>running test 753"
../source/tot_info.exe  < ../inputs/universe/jkABm.mat > ../originals/t753
echo ">>>>>>>>running test 754"
../source/tot_info.exe  < ../inputs/universe/jkABn.mat > ../originals/t754
echo ">>>>>>>>running test 755"
../source/tot_info.exe  < ../inputs/universe/jkABo.mat > ../originals/t755
echo ">>>>>>>>running test 756"
../source/tot_info.exe  < ../inputs/universe/jkABp.mat > ../originals/t756
echo ">>>>>>>>running test 757"
../source/tot_info.exe  < ../inputs/universe/jkAFi.mat > ../originals/t757
echo ">>>>>>>>running test 758"
../source/tot_info.exe  < ../inputs/universe/jkACC.mat > ../originals/t758
echo ">>>>>>>>running test 759"
../source/tot_info.exe  < ../inputs/universe/jkACD.mat > ../originals/t759
echo ">>>>>>>>running test 760"
../source/tot_info.exe  < ../inputs/universe/jkACE.mat > ../originals/t760
echo ">>>>>>>>running test 761"
../source/tot_info.exe  < ../inputs/universe/jkACF.mat > ../originals/t761
echo ">>>>>>>>running test 762"
../source/tot_info.exe  < ../inputs/universe/jkACG.mat > ../originals/t762
echo ">>>>>>>>running test 763"
../source/tot_info.exe  < ../inputs/universe/jkACH.mat > ../originals/t763
echo ">>>>>>>>running test 764"
../source/tot_info.exe  < ../inputs/universe/jkACI.mat > ../originals/t764
echo ">>>>>>>>running test 765"
../source/tot_info.exe  < ../inputs/universe/jkACJ.mat > ../originals/t765
echo ">>>>>>>>running test 766"
../source/tot_info.exe  < ../inputs/universe/jkACK.mat > ../originals/t766
echo ">>>>>>>>running test 767"
../source/tot_info.exe  < ../inputs/universe/jkACL.mat > ../originals/t767
echo ">>>>>>>>running test 768"
../source/tot_info.exe  < ../inputs/universe/jkACM.mat > ../originals/t768
echo ">>>>>>>>running test 769"
../source/tot_info.exe  < ../inputs/universe/jkACN.mat > ../originals/t769
echo ">>>>>>>>running test 770"
../source/tot_info.exe  < ../inputs/universe/jkACO.mat > ../originals/t770
echo ">>>>>>>>running test 771"
../source/tot_info.exe  < ../inputs/universe/jkACP.mat > ../originals/t771
echo ">>>>>>>>running test 772"
../source/tot_info.exe  < ../inputs/universe/jkACQ.mat > ../originals/t772
echo ">>>>>>>>running test 773"
../source/tot_info.exe  < ../inputs/universe/jkACR.mat > ../originals/t773
echo ">>>>>>>>running test 774"
../source/tot_info.exe  < ../inputs/universe/jkACS.mat > ../originals/t774
echo ">>>>>>>>running test 775"
../source/tot_info.exe  < ../inputs/universe/jkACT.mat > ../originals/t775
echo ">>>>>>>>running test 776"
../source/tot_info.exe  < ../inputs/universe/jkACU.mat > ../originals/t776
echo ">>>>>>>>running test 777"
../source/tot_info.exe  < ../inputs/universe/jkACV.mat > ../originals/t777
echo ">>>>>>>>running test 778"
../source/tot_info.exe  < ../inputs/universe/jkACW.mat > ../originals/t778
echo ">>>>>>>>running test 779"
../source/tot_info.exe  < ../inputs/universe/jkACX.mat > ../originals/t779
echo ">>>>>>>>running test 780"
../source/tot_info.exe  < ../inputs/universe/jkACY.mat > ../originals/t780
echo ">>>>>>>>running test 781"
../source/tot_info.exe  < ../inputs/universe/jkACZ.mat > ../originals/t781
echo ">>>>>>>>running test 782"
../source/tot_info.exe  < ../inputs/universe/jkAC[.mat > ../originals/t782
echo ">>>>>>>>running test 783"
../source/tot_info.exe  < ../inputs/universe/jkAC].mat > ../originals/t783
echo ">>>>>>>>running test 784"
../source/tot_info.exe  < ../inputs/universe/jkAC_.mat > ../originals/t784
echo ">>>>>>>>running test 785"
../source/tot_info.exe  < ../inputs/universe/jkACa.mat > ../originals/t785
echo ">>>>>>>>running test 786"
../source/tot_info.exe  < ../inputs/universe/jkACb.mat > ../originals/t786
echo ">>>>>>>>running test 787"
../source/tot_info.exe  < ../inputs/universe/jkACc.mat > ../originals/t787
echo ">>>>>>>>running test 788"
../source/tot_info.exe  < ../inputs/universe/jkACd.mat > ../originals/t788
echo ">>>>>>>>running test 789"
../source/tot_info.exe  < ../inputs/universe/jkACe.mat > ../originals/t789
echo ">>>>>>>>running test 790"
../source/tot_info.exe  < ../inputs/universe/jkACf.mat > ../originals/t790
echo ">>>>>>>>running test 791"
../source/tot_info.exe  < ../inputs/universe/jkACg.mat > ../originals/t791
echo ">>>>>>>>running test 792"
../source/tot_info.exe  < ../inputs/universe/jkACh.mat > ../originals/t792
echo ">>>>>>>>running test 793"
../source/tot_info.exe  < ../inputs/universe/jkACi.mat > ../originals/t793
echo ">>>>>>>>running test 794"
../source/tot_info.exe  < ../inputs/universe/jkACj.mat > ../originals/t794
echo ">>>>>>>>running test 795"
../source/tot_info.exe  < ../inputs/universe/jkAAK.mat > ../originals/t795
echo ">>>>>>>>running test 796"
../source/tot_info.exe  < ../inputs/universe/jkAAL.mat > ../originals/t796
echo ">>>>>>>>running test 797"
../source/tot_info.exe  < ../inputs/universe/jkAAM.mat > ../originals/t797
echo ">>>>>>>>running test 798"
../source/tot_info.exe  < ../inputs/universe/jkAAN.mat > ../originals/t798
echo ">>>>>>>>running test 799"
../source/tot_info.exe  < ../inputs/universe/jkAAO.mat > ../originals/t799
echo ">>>>>>>>running test 800"
../source/tot_info.exe  < ../inputs/universe/jkAAP.mat > ../originals/t800
echo ">>>>>>>>running test 801"
../source/tot_info.exe  < ../inputs/universe/jkAAQ.mat > ../originals/t801
echo ">>>>>>>>running test 802"
../source/tot_info.exe  < ../inputs/universe/jkAAR.mat > ../originals/t802
echo ">>>>>>>>running test 803"
../source/tot_info.exe  < ../inputs/universe/jkAAS.mat > ../originals/t803
echo ">>>>>>>>running test 804"
../source/tot_info.exe  < ../inputs/universe/jkAAT.mat > ../originals/t804
echo ">>>>>>>>running test 805"
../source/tot_info.exe  < ../inputs/universe/jkAAU.mat > ../originals/t805
echo ">>>>>>>>running test 806"
../source/tot_info.exe  < ../inputs/universe/jkAAV.mat > ../originals/t806
echo ">>>>>>>>running test 807"
../source/tot_info.exe  < ../inputs/universe/jkAAW.mat > ../originals/t807
echo ">>>>>>>>running test 808"
../source/tot_info.exe  < ../inputs/universe/jkAAX.mat > ../originals/t808
echo ">>>>>>>>running test 809"
../source/tot_info.exe  < ../inputs/universe/jkAAY.mat > ../originals/t809
echo ">>>>>>>>running test 810"
../source/tot_info.exe  < ../inputs/universe/jkAAZ.mat > ../originals/t810
echo ">>>>>>>>running test 811"
../source/tot_info.exe  < ../inputs/universe/jkAA[.mat > ../originals/t811
echo ">>>>>>>>running test 812"
../source/tot_info.exe  < ../inputs/universe/jkAA].mat > ../originals/t812
echo ">>>>>>>>running test 813"
../source/tot_info.exe  < ../inputs/universe/jkAA_.mat > ../originals/t813
echo ">>>>>>>>running test 814"
../source/tot_info.exe  < ../inputs/universe/jkAAa.mat > ../originals/t814
echo ">>>>>>>>running test 815"
../source/tot_info.exe  < ../inputs/universe/jkAAb.mat > ../originals/t815
echo ">>>>>>>>running test 816"
../source/tot_info.exe  < ../inputs/universe/jkAAc.mat > ../originals/t816
echo ">>>>>>>>running test 817"
../source/tot_info.exe  < ../inputs/universe/jkAAd.mat > ../originals/t817
echo ">>>>>>>>running test 818"
../source/tot_info.exe  < ../inputs/universe/jkAAe.mat > ../originals/t818
echo ">>>>>>>>running test 819"
../source/tot_info.exe  < ../inputs/universe/jkAAf.mat > ../originals/t819
echo ">>>>>>>>running test 820"
../source/tot_info.exe  < ../inputs/universe/jkAAg.mat > ../originals/t820
echo ">>>>>>>>running test 821"
../source/tot_info.exe  < ../inputs/universe/jkAAh.mat > ../originals/t821
echo ">>>>>>>>running test 822"
../source/tot_info.exe  < ../inputs/universe/jkAAi.mat > ../originals/t822
echo ">>>>>>>>running test 823"
../source/tot_info.exe  < ../inputs/universe/jkAAj.mat > ../originals/t823
echo ">>>>>>>>running test 824"
../source/tot_info.exe  < ../inputs/universe/jkAAk.mat > ../originals/t824
echo ">>>>>>>>running test 825"
../source/tot_info.exe  < ../inputs/universe/jkAAl.mat > ../originals/t825
echo ">>>>>>>>running test 826"
../source/tot_info.exe  < ../inputs/universe/jkAAm.mat > ../originals/t826
echo ">>>>>>>>running test 827"
../source/tot_info.exe  < ../inputs/universe/jkAAn.mat > ../originals/t827
echo ">>>>>>>>running test 828"
../source/tot_info.exe  < ../inputs/universe/jkAAo.mat > ../originals/t828
echo ">>>>>>>>running test 829"
../source/tot_info.exe  < ../inputs/universe/jkAAp.mat > ../originals/t829
echo ">>>>>>>>running test 830"
../source/tot_info.exe  < ../inputs/universe/jkAAq.mat > ../originals/t830
echo ">>>>>>>>running test 831"
../source/tot_info.exe  < ../inputs/universe/jkAAr.mat > ../originals/t831
echo ">>>>>>>>running test 832"
../source/tot_info.exe  < ../inputs/universe/jkAAs.mat > ../originals/t832
echo ">>>>>>>>running test 833"
../source/tot_info.exe  < ../inputs/universe/jkAAt.mat > ../originals/t833
echo ">>>>>>>>running test 834"
../source/tot_info.exe  < ../inputs/universe/jkAAu.mat > ../originals/t834
echo ">>>>>>>>running test 835"
../source/tot_info.exe  < ../inputs/universe/jkAAv.mat > ../originals/t835
echo ">>>>>>>>running test 836"
../source/tot_info.exe  < ../inputs/universe/jkAAw.mat > ../originals/t836
echo ">>>>>>>>running test 837"
../source/tot_info.exe  < ../inputs/universe/jkAAx.mat > ../originals/t837
echo ">>>>>>>>running test 838"
../source/tot_info.exe  < ../inputs/universe/jkAAy.mat > ../originals/t838
echo ">>>>>>>>running test 839"
../source/tot_info.exe  < ../inputs/universe/jkABA.mat > ../originals/t839
echo ">>>>>>>>running test 840"
../source/tot_info.exe  < ../inputs/universe/jkABB.mat > ../originals/t840
echo ">>>>>>>>running test 841"
../source/tot_info.exe  < ../inputs/universe/jkABC.mat > ../originals/t841
echo ">>>>>>>>running test 842"
../source/tot_info.exe  < ../inputs/universe/jkABD.mat > ../originals/t842
echo ">>>>>>>>running test 843"
../source/tot_info.exe  < ../inputs/universe/jkABE.mat > ../originals/t843
echo ">>>>>>>>running test 844"
../source/tot_info.exe  < ../inputs/universe/jkABF.mat > ../originals/t844
echo ">>>>>>>>running test 845"
../source/tot_info.exe  < ../inputs/universe/jkABG.mat > ../originals/t845
echo ">>>>>>>>running test 846"
../source/tot_info.exe  < ../inputs/universe/jkABH.mat > ../originals/t846
echo ">>>>>>>>running test 847"
../source/tot_info.exe  < ../inputs/universe/jkABI.mat > ../originals/t847
echo ">>>>>>>>running test 848"
../source/tot_info.exe  < ../inputs/universe/jkABJ.mat > ../originals/t848
echo ">>>>>>>>running test 849"
../source/tot_info.exe  < ../inputs/universe/jkABK.mat > ../originals/t849
echo ">>>>>>>>running test 850"
../source/tot_info.exe  < ../inputs/universe/jkABL.mat > ../originals/t850
echo ">>>>>>>>running test 851"
../source/tot_info.exe  < ../inputs/universe/jkABM.mat > ../originals/t851
echo ">>>>>>>>running test 852"
../source/tot_info.exe  < ../inputs/universe/jkABN.mat > ../originals/t852
echo ">>>>>>>>running test 853"
../source/tot_info.exe  < ../inputs/universe/jkABO.mat > ../originals/t853
echo ">>>>>>>>running test 854"
../source/tot_info.exe  < ../inputs/universe/jkABP.mat > ../originals/t854
echo ">>>>>>>>running test 855"
../source/tot_info.exe  < ../inputs/universe/jkABQ.mat > ../originals/t855
echo ">>>>>>>>running test 856"
../source/tot_info.exe  < ../inputs/universe/jkABR.mat > ../originals/t856
echo ">>>>>>>>running test 857"
../source/tot_info.exe  < ../inputs/universe/jkABS.mat > ../originals/t857
echo ">>>>>>>>running test 858"
../source/tot_info.exe  < ../inputs/universe/new1 > ../originals/t858
echo ">>>>>>>>running test 859"
../source/tot_info.exe  < ../inputs/universe/new10 > ../originals/t859
echo ">>>>>>>>running test 860"
../source/tot_info.exe  < ../inputs/universe/new11 > ../originals/t860
echo ">>>>>>>>running test 861"
../source/tot_info.exe  < ../inputs/universe/new12 > ../originals/t861
echo ">>>>>>>>running test 862"
../source/tot_info.exe  < ../inputs/universe/new13 > ../originals/t862
echo ">>>>>>>>running test 863"
../source/tot_info.exe  < ../inputs/universe/new14 > ../originals/t863
echo ">>>>>>>>running test 864"
../source/tot_info.exe  < ../inputs/universe/new15 > ../originals/t864
echo ">>>>>>>>running test 865"
../source/tot_info.exe  < ../inputs/universe/new16 > ../originals/t865
echo ">>>>>>>>running test 866"
../source/tot_info.exe  < ../inputs/universe/new17 > ../originals/t866
echo ">>>>>>>>running test 867"
../source/tot_info.exe  < ../inputs/universe/new18 > ../originals/t867
echo ">>>>>>>>running test 868"
../source/tot_info.exe  < ../inputs/universe/new19 > ../originals/t868
echo ">>>>>>>>running test 869"
../source/tot_info.exe  < ../inputs/universe/new2 > ../originals/t869
echo ">>>>>>>>running test 870"
../source/tot_info.exe  < ../inputs/universe/new20 > ../originals/t870
echo ">>>>>>>>running test 871"
../source/tot_info.exe  < ../inputs/universe/new21 > ../originals/t871
echo ">>>>>>>>running test 872"
../source/tot_info.exe  < ../inputs/universe/new22 > ../originals/t872
echo ">>>>>>>>running test 873"
../source/tot_info.exe  < ../inputs/universe/new23 > ../originals/t873
echo ">>>>>>>>running test 874"
../source/tot_info.exe  < ../inputs/universe/new24 > ../originals/t874
echo ">>>>>>>>running test 875"
../source/tot_info.exe  < ../inputs/universe/new25 > ../originals/t875
echo ">>>>>>>>running test 876"
../source/tot_info.exe  < ../inputs/universe/new26 > ../originals/t876
echo ">>>>>>>>running test 877"
../source/tot_info.exe  < ../inputs/universe/new27 > ../originals/t877
echo ">>>>>>>>running test 878"
../source/tot_info.exe  < ../inputs/universe/new28 > ../originals/t878
echo ">>>>>>>>running test 879"
../source/tot_info.exe  < ../inputs/universe/new29 > ../originals/t879
echo ">>>>>>>>running test 880"
../source/tot_info.exe  < ../inputs/universe/new3 > ../originals/t880
echo ">>>>>>>>running test 881"
../source/tot_info.exe  < ../inputs/universe/new30 > ../originals/t881
echo ">>>>>>>>running test 882"
../source/tot_info.exe  < ../inputs/universe/new31 > ../originals/t882
echo ">>>>>>>>running test 883"
../source/tot_info.exe  < ../inputs/universe/new32 > ../originals/t883
echo ">>>>>>>>running test 884"
../source/tot_info.exe  < ../inputs/universe/new33 > ../originals/t884
echo ">>>>>>>>running test 885"
../source/tot_info.exe  < ../inputs/universe/new34 > ../originals/t885
echo ">>>>>>>>running test 886"
../source/tot_info.exe  < ../inputs/universe/new35 > ../originals/t886
echo ">>>>>>>>running test 887"
../source/tot_info.exe  < ../inputs/universe/new36 > ../originals/t887
echo ">>>>>>>>running test 888"
../source/tot_info.exe  < ../inputs/universe/new37 > ../originals/t888
echo ">>>>>>>>running test 889"
../source/tot_info.exe  < ../inputs/universe/new38 > ../originals/t889
echo ">>>>>>>>running test 890"
../source/tot_info.exe  < ../inputs/universe/new39 > ../originals/t890
echo ">>>>>>>>running test 891"
../source/tot_info.exe  < ../inputs/universe/new4 > ../originals/t891
echo ">>>>>>>>running test 892"
../source/tot_info.exe  < ../inputs/universe/new40 > ../originals/t892
echo ">>>>>>>>running test 893"
../source/tot_info.exe  < ../inputs/universe/new5 > ../originals/t893
echo ">>>>>>>>running test 894"
../source/tot_info.exe  < ../inputs/universe/new6 > ../originals/t894
echo ">>>>>>>>running test 895"
../source/tot_info.exe  < ../inputs/universe/new7 > ../originals/t895
echo ">>>>>>>>running test 896"
../source/tot_info.exe  < ../inputs/universe/new8 > ../originals/t896
echo ">>>>>>>>running test 897"
../source/tot_info.exe  < ../inputs/universe/new9 > ../originals/t897
echo ">>>>>>>>running test 898"
../source/tot_info.exe  < ../inputs/universe/ntest12 > ../originals/t898
echo ">>>>>>>>running test 899"
../source/tot_info.exe  < ../inputs/universe/ntest13 > ../originals/t899
echo ">>>>>>>>running test 900"
../source/tot_info.exe  < ../inputs/universe/ntest14 > ../originals/t900
echo ">>>>>>>>running test 901"
../source/tot_info.exe  < ../inputs/universe/ntest15 > ../originals/t901
echo ">>>>>>>>running test 902"
../source/tot_info.exe  < ../inputs/universe/ntest16 > ../originals/t902
echo ">>>>>>>>running test 903"
../source/tot_info.exe  < ../inputs/universe/ntest17 > ../originals/t903
echo ">>>>>>>>running test 904"
../source/tot_info.exe  < ../inputs/universe/ntest18 > ../originals/t904
echo ">>>>>>>>running test 905"
../source/tot_info.exe  < ../inputs/universe/ntest19 > ../originals/t905
echo ">>>>>>>>running test 906"
../source/tot_info.exe  < ../inputs/universe/ntest2 > ../originals/t906
echo ">>>>>>>>running test 907"
../source/tot_info.exe  < ../inputs/universe/ntest20 > ../originals/t907
echo ">>>>>>>>running test 908"
../source/tot_info.exe  < ../inputs/universe/ntest21 > ../originals/t908
echo ">>>>>>>>running test 909"
../source/tot_info.exe  < ../inputs/universe/ntest22 > ../originals/t909
echo ">>>>>>>>running test 910"
../source/tot_info.exe  < ../inputs/universe/ntest23 > ../originals/t910
echo ">>>>>>>>running test 911"
../source/tot_info.exe  < ../inputs/universe/ntest24 > ../originals/t911
echo ">>>>>>>>running test 912"
../source/tot_info.exe  < ../inputs/universe/ntest25 > ../originals/t912
echo ">>>>>>>>running test 913"
../source/tot_info.exe  < ../inputs/universe/ntest26 > ../originals/t913
echo ">>>>>>>>running test 914"
../source/tot_info.exe  < ../inputs/universe/ntest27 > ../originals/t914
echo ">>>>>>>>running test 915"
../source/tot_info.exe  < ../inputs/universe/ntest28 > ../originals/t915
echo ">>>>>>>>running test 916"
../source/tot_info.exe  < ../inputs/universe/ntest29 > ../originals/t916
echo ">>>>>>>>running test 917"
../source/tot_info.exe  < ../inputs/universe/ntest3 > ../originals/t917
echo ">>>>>>>>running test 918"
../source/tot_info.exe  < ../inputs/universe/ntest30 > ../originals/t918
echo ">>>>>>>>running test 919"
../source/tot_info.exe  < ../inputs/universe/ntest31 > ../originals/t919
echo ">>>>>>>>running test 920"
../source/tot_info.exe  < ../inputs/universe/ntest32 > ../originals/t920
echo ">>>>>>>>running test 921"
../source/tot_info.exe  < ../inputs/universe/ntest33 > ../originals/t921
echo ">>>>>>>>running test 922"
../source/tot_info.exe  < ../inputs/universe/ntest35 > ../originals/t922
echo ">>>>>>>>running test 923"
../source/tot_info.exe  < ../inputs/universe/ntest36 > ../originals/t923
echo ">>>>>>>>running test 924"
../source/tot_info.exe  < ../inputs/universe/ntest37 > ../originals/t924
echo ">>>>>>>>running test 925"
../source/tot_info.exe  < ../inputs/universe/ntest38 > ../originals/t925
echo ">>>>>>>>running test 926"
../source/tot_info.exe  < ../inputs/universe/ntest39 > ../originals/t926
echo ">>>>>>>>running test 927"
../source/tot_info.exe  < ../inputs/universe/ntest4 > ../originals/t927
echo ">>>>>>>>running test 928"
../source/tot_info.exe  < ../inputs/universe/ntest40 > ../originals/t928
echo ">>>>>>>>running test 929"
../source/tot_info.exe  < ../inputs/universe/ntest41 > ../originals/t929
echo ">>>>>>>>running test 930"
../source/tot_info.exe  < ../inputs/universe/ntest42 > ../originals/t930
echo ">>>>>>>>running test 931"
../source/tot_info.exe  < ../inputs/universe/ntest43 > ../originals/t931
echo ">>>>>>>>running test 932"
../source/tot_info.exe  < ../inputs/universe/ntest44 > ../originals/t932
echo ">>>>>>>>running test 933"
../source/tot_info.exe  < ../inputs/universe/ntest45 > ../originals/t933
echo ">>>>>>>>running test 934"
../source/tot_info.exe  < ../inputs/universe/ntest46 > ../originals/t934
echo ">>>>>>>>running test 935"
../source/tot_info.exe  < ../inputs/universe/ntest48 > ../originals/t935
echo ">>>>>>>>running test 936"
../source/tot_info.exe  < ../inputs/universe/ntest49 > ../originals/t936
echo ">>>>>>>>running test 937"
../source/tot_info.exe  < ../inputs/universe/ntest5 > ../originals/t937
echo ">>>>>>>>running test 938"
../source/tot_info.exe  < ../inputs/universe/ntest50 > ../originals/t938
echo ">>>>>>>>running test 939"
../source/tot_info.exe  < ../inputs/universe/ntest51 > ../originals/t939
echo ">>>>>>>>running test 940"
../source/tot_info.exe  < ../inputs/universe/ntest52 > ../originals/t940
echo ">>>>>>>>running test 941"
../source/tot_info.exe  < ../inputs/universe/ntest53 > ../originals/t941
echo ">>>>>>>>running test 942"
../source/tot_info.exe  < ../inputs/universe/ntest54 > ../originals/t942
echo ">>>>>>>>running test 943"
../source/tot_info.exe  < ../inputs/universe/ntest55 > ../originals/t943
echo ">>>>>>>>running test 944"
../source/tot_info.exe  < ../inputs/universe/ntest56 > ../originals/t944
echo ">>>>>>>>running test 945"
../source/tot_info.exe  < ../inputs/universe/ntest57 > ../originals/t945
echo ">>>>>>>>running test 946"
../source/tot_info.exe  < ../inputs/universe/ntest6 > ../originals/t946
echo ">>>>>>>>running test 947"
../source/tot_info.exe  < ../inputs/universe/ntest7 > ../originals/t947
echo ">>>>>>>>running test 948"
../source/tot_info.exe  < ../inputs/universe/ntest9 > ../originals/t948
echo ">>>>>>>>running test 949"
../source/tot_info.exe  < ../inputs/universe/bnew1 > ../originals/t949
echo ">>>>>>>>running test 950"
../source/tot_info.exe  < ../inputs/universe/bnew10 > ../originals/t950
echo ">>>>>>>>running test 951"
../source/tot_info.exe  < ../inputs/universe/bnew11 > ../originals/t951
echo ">>>>>>>>running test 952"
../source/tot_info.exe  < ../inputs/universe/bnew12 > ../originals/t952
echo ">>>>>>>>running test 953"
../source/tot_info.exe  < ../inputs/universe/bnew13 > ../originals/t953
echo ">>>>>>>>running test 954"
../source/tot_info.exe  < ../inputs/universe/bnew14 > ../originals/t954
echo ">>>>>>>>running test 955"
../source/tot_info.exe  < ../inputs/universe/bnew15 > ../originals/t955
echo ">>>>>>>>running test 956"
../source/tot_info.exe  < ../inputs/universe/bnew16 > ../originals/t956
echo ">>>>>>>>running test 957"
../source/tot_info.exe  < ../inputs/universe/bnew17 > ../originals/t957
echo ">>>>>>>>running test 958"
../source/tot_info.exe  < ../inputs/universe/bnew18 > ../originals/t958
echo ">>>>>>>>running test 959"
../source/tot_info.exe  < ../inputs/universe/bnew19 > ../originals/t959
echo ">>>>>>>>running test 960"
../source/tot_info.exe  < ../inputs/universe/bnew2 > ../originals/t960
echo ">>>>>>>>running test 961"
../source/tot_info.exe  < ../inputs/universe/bnew20 > ../originals/t961
echo ">>>>>>>>running test 962"
../source/tot_info.exe  < ../inputs/universe/bnew21 > ../originals/t962
echo ">>>>>>>>running test 963"
../source/tot_info.exe  < ../inputs/universe/bnew22 > ../originals/t963
echo ">>>>>>>>running test 964"
../source/tot_info.exe  < ../inputs/universe/bnew23 > ../originals/t964
echo ">>>>>>>>running test 965"
../source/tot_info.exe  < ../inputs/universe/bnew24 > ../originals/t965
echo ">>>>>>>>running test 966"
../source/tot_info.exe  < ../inputs/universe/bnew25 > ../originals/t966
echo ">>>>>>>>running test 967"
../source/tot_info.exe  < ../inputs/universe/bnew26 > ../originals/t967
echo ">>>>>>>>running test 968"
../source/tot_info.exe  < ../inputs/universe/bnew27 > ../originals/t968
echo ">>>>>>>>running test 969"
../source/tot_info.exe  < ../inputs/universe/bnew3 > ../originals/t969
echo ">>>>>>>>running test 970"
../source/tot_info.exe  < ../inputs/universe/bnew4 > ../originals/t970
echo ">>>>>>>>running test 971"
../source/tot_info.exe  < ../inputs/universe/bnew5 > ../originals/t971
echo ">>>>>>>>running test 972"
../source/tot_info.exe  < ../inputs/universe/bnew6 > ../originals/t972
echo ">>>>>>>>running test 973"
../source/tot_info.exe  < ../inputs/universe/bnew7 > ../originals/t973
echo ">>>>>>>>running test 974"
../source/tot_info.exe  < ../inputs/universe/bnew8 > ../originals/t974
echo ">>>>>>>>running test 975"
../source/tot_info.exe  < ../inputs/universe/bnew9 > ../originals/t975
echo ">>>>>>>>running test 976"
../source/tot_info.exe  < ../inputs/universe/bnewt1 > ../originals/t976
echo ">>>>>>>>running test 977"
../source/tot_info.exe  < ../inputs/universe/bnewt10 > ../originals/t977
echo ">>>>>>>>running test 978"
../source/tot_info.exe  < ../inputs/universe/bnewt11 > ../originals/t978
echo ">>>>>>>>running test 979"
../source/tot_info.exe  < ../inputs/universe/bnewt12 > ../originals/t979
echo ">>>>>>>>running test 980"
../source/tot_info.exe  < ../inputs/universe/bnewt13 > ../originals/t980
echo ">>>>>>>>running test 981"
../source/tot_info.exe  < ../inputs/universe/bnewt14 > ../originals/t981
echo ">>>>>>>>running test 982"
../source/tot_info.exe  < ../inputs/universe/bnewt15 > ../originals/t982
echo ">>>>>>>>running test 983"
../source/tot_info.exe  < ../inputs/universe/bnewt16 > ../originals/t983
echo ">>>>>>>>running test 984"
../source/tot_info.exe  < ../inputs/universe/bnewt2 > ../originals/t984
echo ">>>>>>>>running test 985"
../source/tot_info.exe  < ../inputs/universe/bnewt3 > ../originals/t985
echo ">>>>>>>>running test 986"
../source/tot_info.exe  < ../inputs/universe/bnewt4 > ../originals/t986
echo ">>>>>>>>running test 987"
../source/tot_info.exe  < ../inputs/universe/bnewt5 > ../originals/t987
echo ">>>>>>>>running test 988"
../source/tot_info.exe  < ../inputs/universe/bnewt6 > ../originals/t988
echo ">>>>>>>>running test 989"
../source/tot_info.exe  < ../inputs/universe/bnewt7 > ../originals/t989
echo ">>>>>>>>running test 990"
../source/tot_info.exe  < ../inputs/universe/bnewt8 > ../originals/t990
echo ">>>>>>>>running test 991"
../source/tot_info.exe  < ../inputs/universe/bnewt9 > ../originals/t991
echo ">>>>>>>>running test 992"
../source/tot_info.exe  < ../inputs/universe/12new1 > ../originals/t992
echo ">>>>>>>>running test 993"
../source/tot_info.exe  < ../inputs/universe/12new10 > ../originals/t993
echo ">>>>>>>>running test 994"
../source/tot_info.exe  < ../inputs/universe/12new11 > ../originals/t994
echo ">>>>>>>>running test 995"
../source/tot_info.exe  < ../inputs/universe/12new12 > ../originals/t995
echo ">>>>>>>>running test 996"
../source/tot_info.exe  < ../inputs/universe/12new13 > ../originals/t996
echo ">>>>>>>>running test 997"
../source/tot_info.exe  < ../inputs/universe/12new14 > ../originals/t997
echo ">>>>>>>>running test 998"
../source/tot_info.exe  < ../inputs/universe/12new15 > ../originals/t998
echo ">>>>>>>>running test 999"
../source/tot_info.exe  < ../inputs/universe/12new16 > ../originals/t999
echo ">>>>>>>>running test 1000"
../source/tot_info.exe  < ../inputs/universe/12new17 > ../originals/t1000
echo ">>>>>>>>running test 1001"
../source/tot_info.exe  < ../inputs/universe/12new18 > ../originals/t1001
echo ">>>>>>>>running test 1002"
../source/tot_info.exe  < ../inputs/universe/12new19 > ../originals/t1002
echo ">>>>>>>>running test 1003"
../source/tot_info.exe  < ../inputs/universe/12new2 > ../originals/t1003
echo ">>>>>>>>running test 1004"
../source/tot_info.exe  < ../inputs/universe/12new20 > ../originals/t1004
echo ">>>>>>>>running test 1005"
../source/tot_info.exe  < ../inputs/universe/12new21 > ../originals/t1005
echo ">>>>>>>>running test 1006"
../source/tot_info.exe  < ../inputs/universe/12new22 > ../originals/t1006
echo ">>>>>>>>running test 1007"
../source/tot_info.exe  < ../inputs/universe/12new23 > ../originals/t1007
echo ">>>>>>>>running test 1008"
../source/tot_info.exe  < ../inputs/universe/12new24 > ../originals/t1008
echo ">>>>>>>>running test 1009"
../source/tot_info.exe  < ../inputs/universe/12new25 > ../originals/t1009
echo ">>>>>>>>running test 1010"
../source/tot_info.exe  < ../inputs/universe/12new26 > ../originals/t1010
echo ">>>>>>>>running test 1011"
../source/tot_info.exe  < ../inputs/universe/12new27 > ../originals/t1011
echo ">>>>>>>>running test 1012"
../source/tot_info.exe  < ../inputs/universe/12new28 > ../originals/t1012
echo ">>>>>>>>running test 1013"
../source/tot_info.exe  < ../inputs/universe/12new29 > ../originals/t1013
echo ">>>>>>>>running test 1014"
../source/tot_info.exe  < ../inputs/universe/12new3 > ../originals/t1014
echo ">>>>>>>>running test 1015"
../source/tot_info.exe  < ../inputs/universe/12new30 > ../originals/t1015
echo ">>>>>>>>running test 1016"
../source/tot_info.exe  < ../inputs/universe/12new31 > ../originals/t1016
echo ">>>>>>>>running test 1017"
../source/tot_info.exe  < ../inputs/universe/12new32 > ../originals/t1017
echo ">>>>>>>>running test 1018"
../source/tot_info.exe  < ../inputs/universe/12new33 > ../originals/t1018
echo ">>>>>>>>running test 1019"
../source/tot_info.exe  < ../inputs/universe/12new34 > ../originals/t1019
echo ">>>>>>>>running test 1020"
../source/tot_info.exe  < ../inputs/universe/12new35 > ../originals/t1020
echo ">>>>>>>>running test 1021"
../source/tot_info.exe  < ../inputs/universe/12new36 > ../originals/t1021
echo ">>>>>>>>running test 1022"
../source/tot_info.exe  < ../inputs/universe/12new37 > ../originals/t1022
echo ">>>>>>>>running test 1023"
../source/tot_info.exe  < ../inputs/universe/12new38 > ../originals/t1023
echo ">>>>>>>>running test 1024"
../source/tot_info.exe  < ../inputs/universe/12new39 > ../originals/t1024
echo ">>>>>>>>running test 1025"
../source/tot_info.exe  < ../inputs/universe/12new4 > ../originals/t1025
echo ">>>>>>>>running test 1026"
../source/tot_info.exe  < ../inputs/universe/12new40 > ../originals/t1026
echo ">>>>>>>>running test 1027"
../source/tot_info.exe  < ../inputs/universe/12new5 > ../originals/t1027
echo ">>>>>>>>running test 1028"
../source/tot_info.exe  < ../inputs/universe/12new6 > ../originals/t1028
echo ">>>>>>>>running test 1029"
../source/tot_info.exe  < ../inputs/universe/12new7 > ../originals/t1029
echo ">>>>>>>>running test 1030"
../source/tot_info.exe  < ../inputs/universe/12new8 > ../originals/t1030
echo ">>>>>>>>running test 1031"
../source/tot_info.exe  < ../inputs/universe/12new9 > ../originals/t1031
echo ">>>>>>>>running test 1032"
../source/tot_info.exe  < ../inputs/universe/12new40 > ../originals/t1032
echo ">>>>>>>>running test 1033"
../source/tot_info.exe  < ../inputs/universe/12new41 > ../originals/t1033
echo ">>>>>>>>running test 1034"
../source/tot_info.exe  < ../inputs/universe/12new42 > ../originals/t1034
echo ">>>>>>>>running test 1035"
../source/tot_info.exe  < ../inputs/universe/12new43 > ../originals/t1035
echo ">>>>>>>>running test 1036"
../source/tot_info.exe  < ../inputs/universe/12new44 > ../originals/t1036
echo ">>>>>>>>running test 1037"
../source/tot_info.exe  < ../inputs/universe/12new45 > ../originals/t1037
echo ">>>>>>>>running test 1038"
../source/tot_info.exe  < ../inputs/universe/12new46 > ../originals/t1038
echo ">>>>>>>>running test 1039"
../source/tot_info.exe  < ../inputs/universe/12new47 > ../originals/t1039
echo ">>>>>>>>running test 1040"
../source/tot_info.exe  < ../inputs/universe/12new48 > ../originals/t1040
echo ">>>>>>>>running test 1041"
../source/tot_info.exe  < ../inputs/universe/12new49 > ../originals/t1041
echo ">>>>>>>>running test 1042"
../source/tot_info.exe  < ../inputs/universe/12new50 > ../originals/t1042
echo ">>>>>>>>running test 1043"
../source/tot_info.exe  < ../inputs/universe/12new51 > ../originals/t1043
echo ">>>>>>>>running test 1044"
../source/tot_info.exe  < ../inputs/universe/12new52 > ../originals/t1044
echo ">>>>>>>>running test 1045"
../source/tot_info.exe  < ../inputs/universe/12new53 > ../originals/t1045
echo ">>>>>>>>running test 1046"
../source/tot_info.exe  < ../inputs/universe/12new54 > ../originals/t1046
echo ">>>>>>>>running test 1047"
../source/tot_info.exe  < ../inputs/universe/12new55 > ../originals/t1047
echo ">>>>>>>>running test 1048"
../source/tot_info.exe  < ../inputs/universe/12new56 > ../originals/t1048
echo ">>>>>>>>running test 1049"
../source/tot_info.exe  < ../inputs/universe/12new57 > ../originals/t1049
echo ">>>>>>>>running test 1050"
../source/tot_info.exe  < ../inputs/universe/12new58 > ../originals/t1050
echo ">>>>>>>>running test 1051"
../source/tot_info.exe  < ../inputs/universe/12new59 > ../originals/t1051
echo ">>>>>>>>running test 1052"
../source/tot_info.exe  < ../inputs/universe/12new60 > ../originals/t1052
